package dk.firma.klient.webservice;

import java.security.cert.X509Certificate;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import dk.gov.oiosi.configuration.ConfigurationException;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.security.CertificateSubject;
import dk.gov.oiosi.security.ldap.LdapCertificateLookup;
import dk.gov.oiosi.security.lookup.CertificateLookupException;
import dk.gov.oiosi.security.revocation.IRevocationLookup;
import dk.gov.oiosi.security.revocation.RevocationException;
import dk.gov.oiosi.security.revocation.RevocationLookupFactory;
import dk.gov.oiosi.security.revocation.RevocationResponse;
import dk.gov.oiosi.security.validation.CertificateExpiredException;
import dk.gov.oiosi.security.validation.CertificateNotActiveException;
import dk.gov.oiosi.security.validation.CertificateValidator;

/**
 * Created by IntelliJ IDEA.
 * User: jlm0578
 * Date: 31-10-11
 * Time: 14:13
 * To change this template use File | Settings | File Templates.
 */
public class TestCertificate
{
    private static Log log = LogFactory.getLog(OiosiRaspClient.class);
    public static final String RaspConfigurationLive = "./Resources/RaspConfiguration.Live.xml";
    public static final String RaspConfigurationTest = "./Resources/RaspConfiguration.Test.xml";

    public TestCertificate() throws Exception, RevocationException
    {

        // First the certificate is retrived from LDAP
        // Then the fate/time is validated
        // last the revocation is check in OCSP

        String subjectString = null;

        // Production configuration
        ConfigurationHandler.setConfigurationFile(RaspConfigurationLive);
        // Production certificates valid
        //subjectString = "CN = NemHandel test service (funktionscertifikat) + SERIALNUMBER = CVR:26769388-FID:1323185774003, O = IT- og Telestyrelsen // CVR:26769388, C = DK";
        //subjectString = "CN=NemHandel Test (funktionscertifikat) + SERIALNUMBER=CVR:32433030-FID:1260947748885, O=mySupply NemHandel // CVR:32433030, C=DK";
        // Production certificates not valid
        //subjectString = "SERIALNUMBER = CVR:26911745-FID:1200662306791 + CN=KMD OIOSI Gateway 2 (funktionscertifikat), O=KMD A/S // CVR:26911745, C=DK";
        // Expired -> // subjectString = "CN = NemHandel test service (funktionscertifikat) + SERIALNUMBER = CVR:26769388-FID:1200406941690, O = IT- og Telestyrelsen // CVR:26769388, C = DK";

        // Test configuration
        //ConfigurationHandler.setConfigurationFile(RaspConfigurationTest);
        // Test certificates valid
        //subjectString = "CN = Testendpoint (funktionscertifikat) + SERIALNUMBER = CVR:26769388-FID:1208430425605, O = IT- og Telestyrelsen // CVR:26769388, C = DK";
        // subjectString = "CN = Testendpoint (funktionscertifikat) + SERIALNUMBER = CVR:26769388-FID:1208430425605, O = IT- og Telestyrelsen // CVR:26769388, C = DK";
          // subjectString = "CN = TEST FOCES1 (funktionscertifikat) + SERIALNUMBER = CVR:30808460-FID:1320135775022, O = DANID A/S // CVR:30808460, C = DK";
        // Test certificates not valid
         //subjectString = "CN = TU GENEREL FOCES gyldig (funktionscertifikat) + SERIALNUMBER = CVR:30808460-FID:94731315, O = Danid A/S // CVR:30808460, C = DK";

       // subjectString = "CN = Test NemHandelservice  (funktionscertifikat) + SERIALNUMBER = CVR:34051178-FID:1329398684312, O = Digitaliseringsstyrelsen // CVR:34051178, C = DK";

        // not valid any more
        // subjectString = "CN=TU GENEREL FOCES gyldig (funktionscertifikat) + SERIALNUMBER=CVR:30808460-FID:94731315, O=Danid A/S // CVR:30808460, C=DK";
        // subjectString = "CN=FOCES1 (funktionscertifikat) + SERIALNUMBER=CVR:30808460-FID:1255692730737, O=DANID A/S // CVR:30808460, C=DK";
        //subjectString = "CN=TU GENEREL MOCES gyldig + SERIALNUMBER=CVR:30808460-RID:45490598, O=Danid A/S // CVR:30808460, C=DK";

        // Use either production Rasp or test Rasp

          subjectString = "CN = mySupply ApS (funktionscertifikat) + SERIALNUMBER = CVR:25894375-FID:1333439025922, O = MYSUPPLY ApS // CVR:25894375, C = DK";

        X509Certificate certificate =  this.retriveCertificateInLdap(subjectString);
        if (certificate != null)
        {
            // The certificate is public, and can be used.
            boolean publicCertificate = this.validateCertificate(certificate);

            if(publicCertificate)
            {
                // Validate if the certificate is Revocation
                IRevocationLookup lookup = RevocationLookupFactory.createRevocationLookupClient();

                RevocationResponse response = this.validateCertificateInOCSP(lookup, certificate);
                if(response.isValid())
                {
                    // allready printed out
                    //log.info("Certificate valid in OCSP");
                }
                else
                {
                    // allready printed out
                    //log.warn("Certificate NOT valid in OCSP");
                }
            }
            else
            {
                log.info("certificate could not be retrived - it is not public.");
            }
        }
    }




    public X509Certificate retriveCertificateInLdap(String subjectString) throws ConfigurationException, RevocationException
    {
        // We can not test a subject string, so retriving the certificate from
        LdapCertificateLookup lookup = new LdapCertificateLookup();
        X509Certificate certificate = null;

        try
        {
            CertificateSubject certificateSubject = new CertificateSubject(subjectString);
            certificate = lookup.getCertificate(certificateSubject);
            log.info("Certificat to validate retrived");
        }
        catch (CertificateNotActiveException e) {
            log.error("Certificat not yet activ!", e);
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        catch (CertificateExpiredException e) {
            log.error("Certificat expired!", e);
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        catch (CertificateLookupException e) {
            log.error("Certificat not retrived!", e);
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }

        /*boolean result = false;
        if(certificate != null)
        {
            RevocationResponse revocationResponse = this.Test(certificate);
            result = revocationResponse.isValid();
        }  */

        return certificate;
    }

    public boolean validateCertificate(X509Certificate certificate)
    {
        boolean result = false;

        try {
            CertificateValidator.validateCertificate(certificate);
            result = true;
        }
        catch (CertificateNotActiveException e) {
            log.info("Certificate not valid - not yet active");
        }
        catch (CertificateExpiredException e) {
            log.info("Certificate not valid - past expired date");
        }

        return result;
    }

    public RevocationResponse validateCertificateInOCSP(IRevocationLookup lookup, X509Certificate x509Certificate) throws RevocationException
    {
        CertificateSubject subject = new CertificateSubject(x509Certificate);
        log.info("Getting the RevocationResponse for: "+subject );
        RevocationResponse revocationResponse = lookup.checkCertificate(x509Certificate);

        if(revocationResponse.isValid())
        {
            log.info("Certificate valid not revoced");
        }
        else
        {
            log.info("Certificate IS revoced!! No longer valid");
        }


        return revocationResponse;
    }

    public static void main(String[] args)
    {
        try
        {
            log.info("Start validate the certificate based on the subject");
            new TestCertificate();
            log.info("Finish");
        }
        catch (RevocationException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        catch (Exception e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }

    }
}
