/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi;

/**
 * Constants used in RASP.
 */
public class Constants {

    /**
     * Namespace for OIOSI RASP.
     */
    public static final String RASP_NAME_SPACE = "http://rep.oio.dk/oiosi.ehandel.gov.dk/xml/schemas/2007/09/01";

    /**
     * Variable in Axis2 MessageContext holding the result of the Schematron
     * check.
     */
    public static final String CHECKED_XML_ELEMENT = "XML_THAT_HAS_BEEN_SCHEMATRON_CHECKED";

    /**
     * Variable in Axis2 MessageContext holding the result of the pruning.
     */
    public static final String PRUNED_XML_ELEMENT = "XML_THAT_HAS_BEEN_PRUNED";

    /**
     * Name of RASP module.
     */
    public static final String RASP_MODULE_NAME = "rasp";

    /**
     * Namespace prefix for RASP custom headers.
     */
    public static final String RASP_CUSTOM_HEADER_PREFIX = "rasp";

    /**
     * Namespace URL for RASP custom headers.
     */
    public static final String RASP_CUSTOM_HEADER_NS = "http://rep.oio.dk/oiosi.ehandel.gov.dk/xml/schemas/2007/09/01/";

    /**
     * Variable in Axis2 MessageContext holding a list of CustomHeaders.
     */
    public static final String RASP_CUSTOM_HEADER_LIST = "RaspHeaderList";

    /**
     * Variable in Axis2 MessageContext holding a list of mandatory headers on serverside which must be copied to reply.
     */
    public static final String RASP_CUSTOM_HEADER_MANDATORY = "RaspHeaderMandatory";

    /**
     * Variable in Axis2 MessageContext holding the MessageIdentifier CustomHeader.
     */
    public static final String RASP_CUSTOM_HEADER_MESSAGE_IDENTIFIER = "RaspHeaderMessageIdentifier";

    /**
     * Variable in Axis2 MessageContext holding the MessageIdentifier (NOT Customheader) 
     */
    public static final String RASP_MESSAGE_IDENTIFIER = "MessageIdentifier";

    /**
     * Variable in Axis2 MessageContext holding the SenderPartyIdentifier as IIdentifier.
     */
    public static final String RASP_SENDER_PARTY_IDENTIFIER = "SenderPartyIdentifier";
    
    /*
     * Header name of the SenderPartyIdentifierType header
     */
    public static final String RASP_SENDER_PARTY_TYPE_HEADER = "SenderPartyIdentifierType";
    
    /**
     * Variable in Axis2 MessageContext holding the ReceiverPartyIdentifier as IIdentifier.
     */
    public static final String RASP_RECEIVER_PARTY_IDENTIFIER = "ReceiverPartyIdentifier";
    
    /*
     * Header name of the ReceiverPartyIdentifierType header
     */
    public static final String RASP_RECEIVER_PARTY_TYPE_HEADER = "ReceiverPartyIdentifierType";
    
    /**
     * Type of PartyIdentifier. 
     */
    public static final String PARTY_IDENTIFIER_TYPE = "type";
    
    /**
     * Variable in Axis2 MessageContext holding the SignatureProof.
     */
    public static final String RASP_SIGNATURE_PROOF = "SignatureProof";

    /**
     * Variable in Axis2 MessageContext holding the Signers Certificate.
     */
    public static final String RASP_SIGNING_CERTIFICATE = "SigningCertificate";

}
