/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.addressing;

import dk.gov.oiosi.communication.Uri;
import dk.gov.oiosi.uddi.EndpointAddressTypeCode;

/**
 * Abstract base class of the address of an endpoint, e.g. a URL or e-mail
 * address. Instantiate this class to represent a specific endpoint address
 * type.
 */
public abstract class EndpointAddress {

    /**
     * Returns the endpoint address in a string representation.
     * 
     * @return Returns the business key in a string representation
     */
    public abstract String getKeyAsString();

    /**
     * Returns the type of endpoint address as a human readable string.
     * 
     * @return Returns the type of string as a human readable string
     */
    public abstract String getKeyTypeAsString();

    /**
     * Returns the UDDI UrlType as a human readable string.
     * 
     * @return UrlType as string
     */
    public abstract String getUrlTypeAsString();

    /**
     * Gets Uri.
     * 
     * @return the endpoint address uri
     */
    public abstract Uri getAsUri();

	public abstract EndpointAddressTypeCode getEndpointAddressTypeCode();
	
	@Override
	public final String toString() {
		return getAsUri().getAbsoluteUri();
	}
}
