/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.addressing;

import java.net.URISyntaxException;

import dk.gov.oiosi.communication.Uri;
import dk.gov.oiosi.uddi.EndpointAddressTypeCode;

/**
 * Represents an URL endpoint address.
 */
public class EndpointAddressHttp extends EndpointAddress {

    /**
     * Endpoint Address.
     */
    private Uri endpointUrl;


    /**
     * Endpoint address url.
     * 
     * @param uri
     *            endpoint url
     */
    public EndpointAddressHttp(final Uri uri) {
        endpointUrl = uri;
    }

    /**
     * Endpoint address url.
     * 
     * @param uri
     *            endpoint url
     * @throws URISyntaxException 
     */
    public EndpointAddressHttp(final String uri) throws URISyntaxException {
        endpointUrl = new Uri(uri);
    }

    /**
     * Gets endpointkey as string.
     * 
     * @return string value of EndpointAddress Uri
     */
    public final String getKeyAsString() {
        return endpointUrl.toString();
    }

    /**
     * Gets keytype as string.
     * 
     * @return keytype 
     */
    public final String getKeyTypeAsString() {
        return "http";
    }

    /**
     * Return the Microsoft.Uddi.UrlType as a sting.
     * 
     * @return url type
     */
    public final String getUrlTypeAsString() {
        return "http";
    }

	@Override
	public EndpointAddressTypeCode getEndpointAddressTypeCode() {
		return EndpointAddressTypeCode.http;
	}

	@Override
	public Uri getAsUri() {
		return endpointUrl;
	}
}
