/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.addressing;

/**
 * Identifier.
 */
public abstract class Identifier {

    /**
     * Determines whether the type of identifier is allowed in the custom rasp headers.
     *
     * @return True, if the identifier is allowed in the custom rasp headers.
     */
    public abstract boolean isAllowedInPublic();

    /**
     * Gets the KeyTypeValue of the IIdentifier
     *
     * @return The key type value of this identifier
     */
    public abstract String getKeyTypeValue();

    /**
     * Get string representation of Identifier.
     *
     * @return identifier as string
     */
    public abstract String getAsString();

    /**
     * Set and Validate Identifier.
     *
     * @param value value of Identifier
     */
    public abstract void set(String value);


    /**
     * Return textual representation of type - eg EAN, CVR...
     *
     * @return type as text
     */
    public abstract String getType();

    @Override
    public final boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }

        if (getClass() != obj.getClass()) {
            return false;
        }
        Identifier other = (Identifier) obj;

        //noinspection SimplifiableIfStatement
        if (!getAsString().equals(other.getAsString())) {
            return false;
        }

        return getKeyTypeValue().equals(other.getKeyTypeValue());
    }

    @Override
    public final int hashCode() {
        return getAsString().hashCode();
    }

    @Override
    public String toString() {
        return getAsString();
    }
}