/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.addressing;

import dk.gov.oiosi.exception.NullOrEmptyArgumentException;

/**
 * EAN Identifier.
 */
public class IdentifierEan extends Identifier {

    
    /**
     * ean representation of Identifier.
     */
    private String eanNumber;

    private static final String keyTypeValue = "http://oio.dk/profiles/OIOSI/1.0/UDDI/Identifiers/eanNumber/";
    
    /**
     * EAN Identifier.
     * 
     * @param value
     *            ean representation of Identifier
     */
    public IdentifierEan(final String value) {
        set(value);
    }

    /* (non-Javadoc)
     * @see dk.gov.oiosi.addressing.IIdentifier#set(java.lang.String)
     */
    public void set(final String value) {
        if (value == null || value.length() == 0) {
            throw new NullOrEmptyArgumentException("eanNumber");
        }
        if (value.length() != 13) {
            throw new IncorrectBusinessIdentifierException("Not a valid ean number [" + value + "], length is not 13.");
        }
        try {
            Long.parseLong(value);
        } catch (NumberFormatException e) {
            throw new IncorrectBusinessIdentifierException("Not a valid ean number [" + value + "], contains non digits.");
        }
        eanNumber = value;
    }

    /**
     * Return the String representation of Identifier.
     * 
     * @return the EAN number as a string
     */
    public String getAsString() {
        return eanNumber;
    }
    
    @Override
    public String getType() {
        return "EAN";
    }

	@Override
	public String getKeyTypeValue() {
		return keyTypeValue;
	}

	@Override
	public boolean isAllowedInPublic() {
		return true;
	}

}
