package dk.gov.oiosi.axis2.module;

import java.math.BigInteger;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.rampart.PolicyBasedResultsValidator;
import org.apache.rampart.RampartException;
import org.apache.rampart.RampartMessageData;
import org.apache.rampart.util.RampartUtil;
import org.apache.ws.security.WSSecurityException;

import dk.gov.oiosi.security.oces.CertificateUtil;

// TODO: DLK: Please describe purpose and use of this new class...
public class OioraspPolicyBasedResultsValidator extends PolicyBasedResultsValidator
{
    /**
     * local log.
     */
    private static final Log log = LogFactory.getLog(OioraspPolicyBasedResultsValidator.class);

/*	@Override
	protected boolean verifyTrust(X509Certificate arg0, RampartMessageData arg1) throws RampartException {
		// in .Net Rasp the class MultipleRootX509CertificateValidator perform equal validation
        boolean isValid = false;


        if(arg0 != null)
        {
            isValid = this.isValid(arg0);
        }

        return isValid;

	}   */

    @Override
    protected boolean verifyTrust(X509Certificate cert, RampartMessageData rmd) throws RampartException {
        // If no certificate was transmitted, do not trust the signature
        if (cert == null) {
            return false;
        }

        String[] aliases;
        String alias;
        X509Certificate[] certs;

        String subjectString = cert.getSubjectDN().getName();
        String issuerString = cert.getIssuerDN().getName();
        BigInteger issuerSerial = cert.getSerialNumber();

        boolean doDebug = log.isDebugEnabled();

        if (doDebug) {
            log.debug("WSHandler: Transmitted certificate has subject " + subjectString);
            log.debug("WSHandler: Transmitted certificate has issuer " + issuerString + " (serial " + issuerSerial + ")");
        }

        // FIRST step
        // Search the keystore for the transmitted certificate

        // Search the keystore for the alias of the transmitted certificate
        try {
            alias = RampartUtil.getSignatureCrypto(
                    rmd.getPolicyData().getRampartConfig(),
                    rmd.getCustomClassLoader()).getAliasForX509Cert(
                    issuerString, issuerSerial);
        } catch (WSSecurityException ex) {
            throw new RampartException("cannotFindAliasForCert", new String[]{subjectString}, ex);
        }

        if (alias != null) {
            // Retrieve the certificate for the alias from the keystore
            try {
                certs = RampartUtil.getSignatureCrypto(
                        rmd.getPolicyData().getRampartConfig(),
                        rmd.getCustomClassLoader()).getCertificates(alias);
            } catch (WSSecurityException ex) {
                throw new RampartException("noCertForAlias", new String[]{alias}, ex);
            }

            // If certificates have been found, the certificates must be compared
            // to ensure againgst phony DNs (compare encoded form including signature)
            if (certs != null && certs.length > 0 && cert.equals(certs[0])) {
                if (doDebug) {
                    log.debug("Direct trust for certificate with " + subjectString);
                }
                return true;
            }
        } else {
            if (doDebug) {
                log.debug("No alias found for subject from issuer with " + issuerString + " (serial " + issuerSerial + ")");
            }
        }

        // SECOND step
        // OIOSI RASP interceptor code
        // The new oces2 certificates has a certificate chain of 3
        // Top    - root certificate
        // middle - issuer certificate
        // buttom - function certificate

        // the issuer certificate is not presendt in the key store, nor should it.
        // so we must download it from ldap to build the certificate chain.

        // Do this requsiv, until a certificate is selv signed, and exist in the tursted certificate store
        boolean rootCertificateFound = false;

        //ICertificateLookup lookup = LdapLookupFactory.createLdapLookupClient();
        List<X509Certificate> list = new ArrayList<X509Certificate>();
        list.add(cert);
        X509Certificate currentCert = cert;
        CertificateUtil certificatUtil = new CertificateUtil();
        //try {
            // hack missing correct exit stament
            while (rootCertificateFound == false) {
                // Now three things can happens.
                //
                //  1) The issue of this currentCert is the root certificate
                //    1.1) The root certificate exist in the trusted key store, this is good - what we are looking for
                //    1.2) The root certificate does not exist int the trusted key store.
                //         we run the iterativ process again, and download the root certificate
                //         However that root certificate will be self signed, and the iterativ process
                //         will break in the above if structure
                //  2) The issue of this certificate is another issuer (not root certificate),
                //     so this iterate process must run again.
                //     We don't know any certificate with more then three levels, but how knows what will happens in the future

                issuerString = currentCert.getIssuerDN().getName();

                // Search the keystore for the alias of the transmitted certificates issuer
                // Either it exist, or it must be downloaded
                try {
                    aliases = RampartUtil.getSignatureCrypto(
                            rmd.getPolicyData().getRampartConfig(),
                            rmd.getCustomClassLoader()).getAliasesForDN(issuerString);
                } catch (WSSecurityException ex) {
                    throw new RampartException("cannotFindAliasForCert", new String[]{issuerString}, ex);
                }

                // If the alias has not been found, the issuer is not in the keystore
                // As a direct result,
                // we need to download the middle certificate
                if (aliases == null || aliases.length < 1) {
                    if (doDebug) {
                        log.debug("No aliases found in keystore for issuer " + issuerString + " of certificate for " + subjectString);
                    }

                    // must be downloaded
                    X509Certificate downloadedCertificate = certificatUtil.downloadIssuerCert(currentCert);

                    if (downloadedCertificate == null) {
                        // The download failes - either because the cert is actual a issuer cert,
                        // and the certificate we tried to download is a root certificate.
                        // but if the root certificate is not in the trusted list, we don't trust it
                        // We are offline, so we can't download - we don't trust it
                        log.debug("Downloaded certificate is null");
                        return false;
                    }

                    // now we have the issue/middle certificate
                    // first - if it self signed it is a root certificate - we don't like that / trust it
                    String downloadedSubjectString = downloadedCertificate.getSubjectDN().getName();
                    String downloadedIssuerString = downloadedCertificate.getIssuerDN().getName();

                    if (downloadedSubjectString.equals(downloadedIssuerString)) {
                        // the certificate is self signed - not good
                        // this means that the root certificate was not in the trusted key store, so we downloaded it
                        // but - if the root certificate is not in the trusted key store - we don't trust it
                        // so return false
                        return false;
                    }

                    list.add(downloadedCertificate);
                    currentCert = downloadedCertificate;
                    // the iterate process must run again
                } else {
                    // trusted root certificate found in key store
                    // retrieve it
                    // break the while loop, and then validate if the certificate is valid
                    rootCertificateFound = true;

                    // THIRD step
                    // Check the certificate trust path for every alias of the issuer found in the keystore
                    for (int i = 0; i < aliases.length; i++) {
                        alias = aliases[i];

                        if (doDebug) {
                            log.debug("Preparing to validate certificate path with alias " + alias + " for issuer " + issuerString);
                        }

                        // Retrieve the certificate(s) for the alias from the keystore
                        try {
                            certs = RampartUtil.getSignatureCrypto(
                                    rmd.getPolicyData().getRampartConfig(),
                                    rmd.getCustomClassLoader()).getCertificates(alias);
                        } catch (WSSecurityException ex) {
                            throw new RampartException("noCertForAlias", new String[]{alias}, ex);
                        }

                        // If no certificates have been found, there has to be an error:
                        // The keystore can find an alias but no certificate(s)
                        if (certs == null || certs.length < 1) {
                            throw new RampartException("noCertForAlias", new String[]{alias});
                        }

                        // Form a certificate chain from the transmitted certificate
                        // and the certificate(s) of the issuer from the keystore
                        // First, create new array
                        X509Certificate[] x509certs = new X509Certificate[certs.length + list.size()];
                        // Then add the first (and downloaded) certificate ...
                        int indexList;
                        for (indexList = 0; indexList  < list.size(); indexList++) {
                            cert = list.get(indexList);
                            x509certs[indexList] = cert;
                        }

                        // ... and the other certificates from the key store
                        for (int j = 0; j < certs.length; j++) {
                            cert = certs[j];
                            x509certs[j + indexList] = cert;
                        }

                        certs = x509certs;

                        // Use the validation method from the crypto to check whether the subjects certificate was really signed by the issuer stated in the certificate
                        try {
                            if (RampartUtil.getSignatureCrypto(
                                    rmd.getPolicyData().getRampartConfig(),
                                    rmd.getCustomClassLoader()).validateCertPath(certs)) {
                                if (doDebug) {
                                    log.debug("WSHandler: Certificate path has been verified for certificate with subject " + subjectString);
                                }
                                return true;
                            }
                        } catch (WSSecurityException ex) {
                            throw new RampartException("certPathVerificationFailed", new String[]{subjectString}, ex);
                        }
                    }
                }
            }
        //}


        log.debug("WSHandler: Certificate path could not be verified for certificate with subject " + subjectString);
        return false;
    }
}
