/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.axis2.module.customheaders;

import java.util.List;

import org.apache.axiom.soap.SOAPEnvelope;
import org.apache.axiom.soap.SOAPHeader;
import org.apache.axiom.soap.SOAPHeaderBlock;
import org.apache.axis2.AxisFault;
import org.apache.axis2.context.MessageContext;
import org.apache.axis2.context.OperationContext;
import org.apache.axis2.description.HandlerDescription;
import org.apache.axis2.description.Parameter;
import org.apache.axis2.wsdl.WSDLConstants;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import dk.gov.oiosi.axis2.module.RaspHandler;
import dk.gov.oiosi.axis2.module.RaspModule;
import dk.gov.oiosi.policy.OiosiPolicyBean;

/**
 * Add custom headers to outgoing messages.
 */
public class CustomHeaderOutHandler extends RaspHandler {

    private static final Log log = LogFactory.getLog(CustomHeaderOutHandler.class);
    private static HandlerDescription EMPTY_HANDLER_METADATA = new HandlerDescription("deafult Handler");
    private HandlerDescription handlerDesc;
    public static final String NAME = "CustomHeaderOutHandler";


    /**
     * Constructor.
     */
    public CustomHeaderOutHandler() {
        this.handlerDesc = EMPTY_HANDLER_METADATA;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#init(org.apache.axis2.description.HandlerDescription)
     */
    public void init(HandlerDescription handlerdesc) {
        this.handlerDesc = handlerdesc;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#invoke(org.apache.axis2.context.MessageContext)
     */
    @SuppressWarnings("unchecked")
	public InvocationResponse invoke(MessageContext msgContext) throws AxisFault {
    	log.debug("CustomHeaderOutHandler : invoke " + msgContext.getSoapAction());

    	if (!msgContext.isEngaged(RaspModule.MODULE_NAME)) {
            log.debug("Rasp module not engaged - skip");
            return InvocationResponse.CONTINUE;
        }

        OiosiPolicyBean oiosiPolicyBean = getPolicyBean(msgContext);
        if (!oiosiPolicyBean.doCustomHeaders()) {
            log.debug(" - policy defined skip...");
            return InvocationResponse.CONTINUE;
        }

        OperationContext operationContext = msgContext.getOperationContext();
        MessageContext incomingMessageContext = operationContext.getMessageContext(WSDLConstants.MESSAGE_LABEL_IN_VALUE);
        
        Object transferedList;
        if(incomingMessageContext != null)
        	transferedList = incomingMessageContext.getProperty(dk.gov.oiosi.Constants.RASP_CUSTOM_HEADER_MANDATORY);
        else
        	transferedList = msgContext.getProperty(dk.gov.oiosi.Constants.RASP_CUSTOM_HEADER_MANDATORY);
        	
        	
        Object transferedMessageId = msgContext.getProperty(dk.gov.oiosi.Constants.RASP_CUSTOM_HEADER_MESSAGE_IDENTIFIER);
        
        log.trace("CustomHeader List : " + transferedList);
        log.trace("MessageIdentifier : " + transferedMessageId);
        if (transferedList == null && transferedMessageId == null) {
            log.debug("No Custom Headers to set");
            return InvocationResponse.CONTINUE;
        }

        SOAPEnvelope envelope = msgContext.getEnvelope();
        SOAPHeader header = envelope.getHeader();
        
        List<SOAPHeaderBlock> customHeaderList = (List<SOAPHeaderBlock>) transferedList;

        boolean rmMessage = RaspModule.getInstance().isRMNamespaceByAction(msgContext.getSoapAction());

        for (int i = 0; i < customHeaderList.size(); i++) {
            SOAPHeaderBlock shb = (SOAPHeaderBlock) customHeaderList.get(i);
            if (dk.gov.oiosi.Constants.RASP_MESSAGE_IDENTIFIER.equals(shb.getLocalName()) && rmMessage) {
                // SKIP MessageIdentifier for RM
            } else {
                log.debug("Add : " + shb.getLocalName());
                if(msgContext.getProperty("OutgoingHeadersAdded") == null){
                	SOAPHeaderBlock newHeader = header.addHeaderBlock(shb.getLocalName(), shb.getNamespace());
                	newHeader.setText(shb.getText());
                }
            }
 
        }

        if (!rmMessage && transferedMessageId != null) {
            log.debug("Add : MessageIdentifier" + transferedMessageId);
            SOAPHeaderBlock msgId = (SOAPHeaderBlock)transferedMessageId;
            if(msgContext.getProperty("OutgoingHeadersAdded") == null){
	            SOAPHeaderBlock newHeader = header.addHeaderBlock(msgId.getLocalName(), msgId.getNamespace());
	            newHeader.setText(msgId.getText());
            }
        }
        
        
        msgContext.setProperty("OutgoingHeadersAdded", true);
        
        return InvocationResponse.CONTINUE;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#flowComplete(org.apache.axis2.context.MessageContext)
     */
    public void flowComplete(MessageContext arg0) {
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#getName()
     */
    public String getName() {
        return NAME;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#getParameter(java.lang.String)
     */
    public Parameter getParameter(String name) {
        return this.handlerDesc.getParameter(name);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#getHandlerDesc()
     */
    public HandlerDescription getHandlerDesc() {
        return handlerDesc;
    }

}
