/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.axis2.module.mailtransportfix;

import org.apache.axis2.AxisFault;
import org.apache.axis2.Version;
import org.apache.axis2.context.MessageContext;
import org.apache.axis2.description.HandlerDescription;
import org.apache.axis2.description.Parameter;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import dk.gov.oiosi.axis2.module.RaspHandler;

/**
 * Handle error in Axis for mailtransport. Toggles 'serverside' variable.
 */
public class MailtransportExceptionFixInHandler extends RaspHandler {


    private static final Log log = LogFactory.getLog(MailtransportExceptionFixInHandler.class);
    public static final String NAME = "MailtransportExceptionFixInHandler";
    private static HandlerDescription EMPTY_HANDLER_METADATA = new HandlerDescription("deafult Handler");
    private HandlerDescription handlerDesc;

    /**
     * Constructor.
     */
    public MailtransportExceptionFixInHandler() {
        this.handlerDesc = EMPTY_HANDLER_METADATA;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#init(org.apache.axis2.description.HandlerDescription)
     */
    public void init(HandlerDescription handlerdesc) {
        this.handlerDesc = handlerdesc;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#flowComplete(org.apache.axis2.context.MessageContext)
     */
    public void flowComplete(MessageContext ctx) {

        log.debug("MailtransportExceptionFixInHandler . flowComplete : Axis2 version [" + Version.getVersionText() + "] : "
                + ctx.getFailureReason() + " : " + ctx.getFaultTo());

        if (ctx.isServerSide()) {

            if (ctx.getTransportIn() != null && "mailto".equals(ctx.getTransportIn().getName()) && ctx.getFailureReason() != null) {
                log.warn("Change ServerSide to false - to circumvent Axis2 1.4  mailtransport Fault problem.");

                ctx.setServerSide(false);

                ctx.setProperty("MailtransportExceptionFix", "true");

            }
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#getHandlerDesc()
     */
    public HandlerDescription getHandlerDesc() {
        return handlerDesc;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#getName()
     */
    public String getName() {
        return NAME;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#getParameter(java.lang.String)
     */
    public Parameter getParameter(String arg0) {
        //This particular handler has no parameters
        return null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.axis2.engine.Handler#invoke(org.apache.axis2.context.MessageContext)
     */
    public InvocationResponse invoke(MessageContext ctx) throws AxisFault {
        log.debug("MailtransportExceptionFixInHandler . invoke");

        // handle in flow complete if needed
        return InvocationResponse.CONTINUE;
    }

}
