/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.common;

import java.util.UUID;

/**
 * Wrap Axiom Guid.
 */
public class Guid {

    /**
     * Value of GUID.
     */
    private UUID guid;

    /**
     * Construct new GUID with new random uid.
     */
    public Guid() {
        guid = UUID.randomUUID();
    }

    /**
     * Construct new GUID based on argument.
     * 
     * @param argument
     *            GUID value
     */
    public Guid(final String argument) {
        guid = UUID.fromString(argument);
    }

    /**
     * GUID.
     * 
     * @return value of GUID
     */
    public final String getGuid() {
        return guid.toString();
    }

    /**
     * GUID Factory.
     * 
     * @return new Guid
     */
    public static Guid newGuid() {
        return new Guid();
    }

	@Override
	public int hashCode() {
		return guid.hashCode();
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Guid other = (Guid) obj;
		if (guid == null) {
			if (other.guid != null)
				return false;
		} else if (!guid.equals(other.guid))
			return false;
		return true;
	}

	public static boolean validateString(String guidString) {
		try {
			UUID uuid = UUID.fromString(guidString);
			return uuid.toString().equals(guidString);
		} catch (IllegalArgumentException e) {
			return false;
		}
	}
	
	@Override
	public String toString(){
		return getGuid();
	}
	
	
}
