/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and 
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */


package dk.gov.oiosi.common.cache;

import java.util.Map;

import dk.gov.oiosi.common.OutVariable;

/**
 * Interface that represents a simple cache 
 */
public interface ICache<TKey, TValue> {
	
	public static final String CONFIG_CACHE_NAME = "CacheName";

	/**
     * Adds the key-value pair to the cache.
     * 
     * @param key
     *            key for cached item
     * @param value
     *            item to cache
     */
    void add(TKey key, TValue value);

    /**
     * Sets the value of the specified key. Overwrites value if already present.
     * 
     * @param key key for cached item
     * @param value item to cache
     */
    void set(TKey key, TValue value);
    
    /**
     * Lookup whether a given key is represented in the cache.
     * 
     * @param key
     *            key to search for
     * @return true if key exists
     */
    boolean containsKey(TKey key);

    /**
     * Removes a given key-value pair from the cache, based on the key.
     * 
     * @param key
     *            remove item for key
     */
    void remove(TKey key);

    /**
     * Try to get the value from a given key.
     * 
     * @param key
     *            search for item with key
     * @return value or null if unknown
     */
    boolean tryGetValue(TKey key, OutVariable<TValue> value);

    /**
     * Check the validity of the data in the cache
     * 
     * @return number of expired cache entries
     */
	/*
	 * dlk, 2012-04-05
	 * 
	 * In the code, which was posted to digitalizer.dk regarding propositions
	 * for improvements of caches, TimedCache was modified to return integer in
	 * this method. Let's keep it.
	 */
    int checkExpired();

	/**
	 * @return configuration map for this cache instance. Can be used by cache
	 *         clients to pass them additional configuraiton parameters. Can
	 *         return null.
	 */
    Map<String, String> getConfiguration();
}
