/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */


package dk.gov.oiosi.common.cache;

import java.util.Calendar;

/**
 * Internal cache entry class.
 */
public class TimedCacheValue<T> {
    /**
     * timeout for entry.
     */
    private long timeOut;

    /**
     * cached element.
     */
    private T value;

    /**
     * Construct cache entry.
     *
     * @param t
     *            timeout for entry
     * @param v
     *            value of entry
     */
    public TimedCacheValue(final long t, final T v) {
        timeOut = t;
        value = v;
    }

    /**
     * timeout for entry.
     *
     * @return timeout
     */
    public final long getTimeOut() {
        return timeOut;
    }

    /**
     * Value.
     *
     * @return value
     */
    public final T getValue() {
        return value;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("[timeOut=");
        Calendar c = Calendar.getInstance();
        c.setTimeInMillis(timeOut);
        sb.append(c.getTime());
        sb.append(", value=");
        if (value != null) {
            sb.append(value);
        } else {
            sb.append("null");
        }
        sb.append("]");
        return sb.toString();
    }
}
