package dk.gov.oiosi.common.cache.holder;

import dk.gov.oiosi.common.cache.MultipleQuantityCache;

/**
 * Simple value holder for {@link MultipleQuantityCache} caches. Supposes to be
 * used for implementation of Least recently used algorithm.
 * 
 * @author Dmitriy Lapko, TrueLink A/S
 * 
 * @param <TKey>
 * @param <TValue>
 */
public class SimpleValueHolder<TKey, TValue> implements IMultipleQuantityValueHolder<TKey, TValue> {

	protected final TKey key;
	/*
	 * Marked as volatile so all threads are aware about changes in this value.
	 */
	protected volatile TValue value;
	/**
	 * Index which shows at which number of cache usage this key was returned.
	 */
	/*
	 * Marked as volatile so all threads are aware about changes in this value.
	 */
	protected volatile int usageIndex;

	public SimpleValueHolder(TKey key) {
		this.key = key;
	}

	@Override
	public TValue getValue() {
		return this.value;
	}

	@Override
	public int incrementUseCount(int cacheUsageIndex) {
		this.usageIndex = cacheUsageIndex;
		return cacheUsageIndex;
	}

	@Override
	public int getUseCount() {
		return usageIndex;
	}

	@Override
	public TKey getKey() {
		return this.key;
	}

	@Override
	public void add(TValue value) {
		this.value = value;
	}

	@Override
	public boolean isEmpty() {
		return value == null;
	}

	@Override
	public String toString() {
		StringBuffer sb = new StringBuffer();
		sb.append("used=");
		sb.append(usageIndex);
		sb.append(", value=");
		sb.append(value);
		return sb.toString();
	}
}
