package dk.gov.oiosi.common.cache.stat;

import dk.gov.oiosi.common.cache.ICache;

/**
 * Abstract class for cache implementations to collect cache usage statistics
 * for all {@link ICache} methods and their results
 *
 * @author Dmitriy Lapko, TrueLink A/S
 * @since OIORASP 1.3.0
 *
 * @param <TKey>
 * @param <TValue>
 */
public abstract class AbstractStatisticsCollectorCache<TKey, TValue> implements ICache<TKey, TValue> {

	protected final CacheStatisticsData statData;

	public AbstractStatisticsCollectorCache() {
		statData = buildStatisticsDataContainer();
	}

	/*
	 * Extracted to a separate method to allow implementations to use their
	 * custom class for cache statistics data if it is needed
	 */
	protected CacheStatisticsData buildStatisticsDataContainer() {
		return new CacheStatisticsData();
	}

	public CacheStatisticsData getStatData() {
		return statData;
	}
}
