/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.communication.configuration;

/**
 * Definition of a RASP endpoint type.
 */
public class DocumentEndpointInformation {

    /**
     * requestAction.
     */
    private String requestAction = "";

    /**
     * replyAction. 
     */
    private String replyAction = "";

    /**
     * endpointFriendlyName.
     */
    private ServiceEndpointFriendlyName endpointFriendlyName = new ServiceEndpointFriendlyName();

    /**
     * senerFriendlyName.
     */
    private ServiceEndpointFriendlyName senderFriendlyName = new ServiceEndpointFriendlyName();

    /**
     * Receiver key in document.
     */
    private ServiceEndpointKey key = new ServiceEndpointKey();

    /**
     * Sender key in document.
     */
    private ServiceEndpointKey senderKey = new ServiceEndpointKey();

    /**
     * Constructor.
     */
    public DocumentEndpointInformation() {
    }

    /**
     * Constructor
     * 
     * @param requestAction
     *            The SOAP action associated with requests to endpoints of this
     *            type
     * @param replyAction
     *            The SOAP action expected to be returned by endpoints of this
     *            type
     * @param friendlyNameXpath
     *            Xpath to the human reader friendly name of this endpoint (e.g.
     *            "Ministry of Science, Denmark")
     * @param endpointKey
     *            Information about the endpoint unique ID, used for UDDI
     *            lookups
     * @param senderFriendlyNameXpath
     *            The xpath to the human reader friendly name of the sender
     * @param senderEndpointKey
     *            The endpoint key of the sender
     */
    public DocumentEndpointInformation(String requestAction, String replyAction, ServiceEndpointFriendlyName friendlyNameXpath,
            ServiceEndpointKey endpointKey, ServiceEndpointFriendlyName senderFriendlyNameXpath, ServiceEndpointKey senderEndpointKey) {
        this.requestAction = requestAction;
        this.replyAction = replyAction;
        endpointFriendlyName = friendlyNameXpath;
        key = endpointKey;
        senderFriendlyName = senderFriendlyNameXpath;
        senderKey = senderEndpointKey;
    }

    /**
     * The SOAP action associated with endpoints of this type
     * 
     * @return RequestAction
     */
    public String getRequestAction() {
        return requestAction;
    }

    /**
     * The SOAP action associated with endpoints of this type
     * 
     * @param value
     *            RequestAction
     */
    public void setRequestAction(String value) {
        requestAction = value;
    }

    /**
     * The SOAP action returned by endpoints of this type
     * 
     * @return ReplyAction
     */
    public String getReplyAction() {
        return replyAction;
    }

    /**
     * The SOAP action returned by endpoints of this type
     * 
     * @param value
     *            ReplyAction
     */
    public void setReplyAction(String value) {
        replyAction = value;
    }

    /**
     * The xpath to the human reader friendly name of this endpoint (e.g.
     * "Ministry of Science, Denmark").
     * 
     * @return EndpointFriendlyName
     */
    public ServiceEndpointFriendlyName getEndpointFriendlyName() {
        return endpointFriendlyName;
    }

    /**
     * The xpath to the human reader friendly name of this endpoint (e.g.
     * "Ministry of Science, Denmark").
     * 
     * @param value
     *            EndpointFriendlyName
     */
    public void setEndpointFriendlyName(ServiceEndpointFriendlyName value) {
        endpointFriendlyName = value;
    }

    /**
     * The xpath to the human reader friendly name of the sender (e.g. "Ministry
     * of Science, Denmark").
     * 
     * @return SenderFriendlyName
     */
    public ServiceEndpointFriendlyName getSenderFriendlyName() {
        return senderFriendlyName;
    }

    /**
     * The xpath to the human reader friendly name of the sender (e.g. "Ministry
     * of Science, Denmark").
     * 
     * @param value
     *            SenderFriendlyName
     */
    public void setSenderFriendlyName(ServiceEndpointFriendlyName value) {
        senderFriendlyName = value;
    }

    /**
     * Information about the endpoint unique ID, used for UDDI lookups.
     * 
     * @return Key
     */
    public ServiceEndpointKey getKey() {
        return key;
    }

    /**
     * Information about the endpoint unique ID, used for UDDI lookups.
     * 
     * @value param Key
     */
    public void setKey(ServiceEndpointKey value) {
        key = value;
    }

    /**
     * Information about the sending endpoint unique ID.
     * 
     * @return SenderKey
     */
    public ServiceEndpointKey getSenderKey() {
        return senderKey;
    }

    /**
     * Information about the sending endpoint unique ID.
     * 
     * @param value
     *            SenderKey
     */
    public void setSenderKey(ServiceEndpointKey value) {
        senderKey = value;
    }

}
