/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and 
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.communication.configuration;

/**
 * Represents a mapping between between profile name and profile uddi id
 */
public class ProfileMapping {

	private String _name;
    private String _tModelGuid;

    /**
     * Constructs an empty profile mapping
     */
    public ProfileMapping() {
        _name = "";
        _tModelGuid = "";
    }

    /**
     * Constructs a profile mapping with the given name and guid
     * @param name The profile name
     * @param tModelGuid The profile UDDI GUID
     */
    public ProfileMapping(String name, String tModelGuid) {
        _name = name;
        _tModelGuid = tModelGuid;
    }

    /**
     * Sets the name of the profile.
     * @param value The name
     */
    public void setName(String value) {
    	_name = value;
    }
    
    /**
     * Gets the name of the profile.
     * @return The profile name
     */
    public String getName() {
    	return _name;
    }

    /**
     * Sets the UDDI GUID
     * @param value The GUID to set
     */
    public void setTModelGuid(String value) {
    	_tModelGuid = value;
    }
    
    /**
     * Gets the UDDI GUID
     * @return The GUID
     */
    public String getTModelGuid() {
    	return _tModelGuid;
    }
}