/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.raspprofile.communication;

import dk.gov.oiosi.communication.*;
import dk.gov.oiosi.exception.MainException;

/**
 * This is an interface for a RASP request.
 */
public interface IRaspRequest {

    /**
     * Synchronously sends a request and gets a response
     *
     * @param message    Request message
     * @param documentId Document Id
     * @return Response message
     * @throws MainException On error...
     */
    Response getResponse(OiosiMessage message, String documentId) throws MainException;

    /**
     * Get the credentials
     *
     * @return The credentials
     */
    Credentials getCredentials();

    /**
     * Sets the credentials
     *
     * @param cred The credentials to set for this instance
     */
    void setCredentials(Credentials cred);

    /**
     * Gets the send policy
     *
     * @return The policy
     */
    SendPolicy getPolicy();

    /**
     * Sets the send policy
     *
     * @param policy The new policy
     */
    void setPolicy(SendPolicy policy);

    /**
     * Gets the request Uri
     *
     * @return The Uri
     */
    Uri getRequestUri();
}