/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.security;

import dk.gov.oiosi.security.oces.OcesCertificateType;

/**
 * This class' public properties are used to store the result of a certification
 * validation.
 */
public class CertificateCheckResult {

    /**
     * everything ok.
     */
    private boolean allTestsPassed;

    /**
     * root certificate ???.
     */
    private boolean rootCertificateAsRoot;

    /**
     * root certificate ok - activated.
     */
    private boolean rootCertificateActivated;

    /**
     * root certificate ok - valid.
     */
    private boolean rootCertificateValid;

    /**
     * certificate ok - activated.
     */
    private boolean certificateActivated;

    /**
     * certificate ok - valid.
     */
    private boolean certificateValid;

    /**
     * certificate revoked.
     */
    private boolean certificateRevoked;

    /**
     * certificate type.
     */
    private OcesCertificateType certificateType;

    /**
     * All tests have been passed.
     * 
     * @return AllTestsPassed
     */
    public boolean getAllTestsPassed() {
        return allTestsPassed;
    }

    /**
     * All tests have been passed.
     * 
     * @param value
     *            AllTestsPassed
     */
    public void setAllTestsPassed(boolean value) {
        allTestsPassed = value;
    }

    /**
     * Indicates if a chainvalidation has been successfull.
     * 
     * @return RootCertificateAsRoot
     */
    public boolean getRootCertificateAsRoot() {
        return rootCertificateAsRoot;
    }

    /**
     * Indicates if a chainvalidation has been successfull.
     * 
     * @param value
     *            RootCertificateAsRoot
     */
    public void setRootCertificateAsRoot(boolean value) {
        rootCertificateAsRoot = value;
    }

    /**
     * Indicates if the rootcertificate is activated.
     * 
     * @return RootCertificateActivated
     */
    public boolean getRootCertificateActivated() {
        return rootCertificateActivated;
    }

    /**
     * Indicates if the rootcertificate is activated.
     * 
     * @param value
     *            RootCertificateActivated
     */
    public void setRootCertificateActivated(boolean value) {
        rootCertificateActivated = value;
    }

    /**
     * Indicates if the root certificate is valid (is not expired).
     * 
     * @return RootCertificateValid
     */
    public boolean getRootCertificateValid() {
        return rootCertificateValid;
    }

    /**
     * Indicates if the root certificate is valid (is not expired).
     * 
     * @param value
     *            RootCertificateValid
     */
    public void setRootCertificateValid(boolean value) {
        rootCertificateValid = value;
    }

    /**
     * Indicates if the certificate is activated.
     * 
     * @return CertificateActivated
     */
    public boolean getCertificateActivated() {
        return certificateActivated;
    }

    /**
     * Indicates if the certificate is activated.
     * 
     * @param value
     *            CertificateActivated
     */
    public void setCertificateActivated(boolean value) {
        certificateActivated = value;
    }

    /**
     * Indicates if the certificate is valid (is not expired).
     * 
     * @return CertificateValid
     */
    public boolean getCertificateValid() {
        return certificateValid;
    }

    /**
     * Indicates if the certificate is valid (is not expired).
     * 
     * @param value
     *            CertificateValid
     */
    public void setCertificateValid(boolean value) {
        certificateValid = value;
    }

    /**
     * Indicates if the certificate has been revoked.
     * 
     * @return CertificateRevoked
     */
    public boolean getCertificateRevoked() {
        return certificateRevoked;
    }

    /**
     * Indicates if the certificate has been revoked.
     * 
     * @param value
     *            CertificateRevoked
     */
    public void setCertificateRevoked(boolean value) {
        certificateRevoked = value;
    }

    /**
     * The type of the OCES certificate.
     * 
     * @return OcesCertificateType
     */
    public OcesCertificateType getCertificateType() {
        return certificateType;
    }

    /**
     * The type of the OCES certificate.
     * 
     * @param value
     *            OcesCertificateType
     */
    public void setCertificateType(OcesCertificateType value) {
        certificateType = value;
    }

}
