/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.security;

import dk.gov.oiosi.exception.ArgumentNullException;

import java.security.cert.X509Certificate;

/**
 * Represents the Subject Number of an OCES certificate. Example format:
 * 'SERIALNUMBER=CVR:25767535-UID:1100080130597 + CN=TDC TOTALL�SNINGER A/S -
 * TDC Test, O=TDC TOTALL�SNINGER A/S // CVR:25767535, C=DK' Note that windows
 * certificate viewer shows these differently
 */
public class CertificateIssuerSubject extends CertificateSubject {

    private String subjectString;

    /**
     * Constructor that takes a string representation of the certificate subject.
     *
     * @param subject Subject string to parse
     */
    public CertificateIssuerSubject(String subject) {
        if (subject == null) {
            throw new ArgumentNullException("CertificateSubject");
        }

        subjectString = subject;
    }

    /**
     * Constructor that extracts the subject from a X509 certificate.
     *
     * @param certificate The X509 certificate
     */
    public CertificateIssuerSubject(X509Certificate certificate) {
        if (certificate == null) {
            throw new ArgumentNullException("CertificateSubject");
        }

        subjectString = certificate.getIssuerDN().getName();

        //X500Principal x500 =  certificate.getSubjectX500Principal();
        //String name = x500.getName(X500Principal.RFC1779);
//
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof CertificateIssuerSubject)) {
            return false;
        }

        CertificateIssuerSubject other = (CertificateIssuerSubject) obj;
        return other.toString().equals(this.toString());
    }

    @Override
    public int hashCode() {
        return this.toString().hashCode();
    }

    @Override
    public String toString() {
        return subjectString;
    }
}