/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.security.oces;

import dk.gov.oiosi.exception.MainException;

import java.security.cert.X509Certificate;

/**
 * Represents an employee oces x509 certificate.
 *
 * @deprecated From RASP 1.3.0 this is deprecated.
 */
public class EmployeeOcesX509Certificate extends OcesX509Certificate {

    /**
     * cvr number for company.
     */
    private String cvrNumber;

    /**
     * Constructor that takes an x509 certificate as parameter. If the
     * certificate is not an employee certificate an exception is thrown.
     *
     * @param certificate certificate
     * @throws MainException
     */
    public EmployeeOcesX509Certificate(X509Certificate certificate) throws MainException {
        super(certificate);

        if (getOcesCertificateType().getType() != OcesCertificateType.OcesEmployee) {
            throw new InvalidOcesEmployeeCertificateException(certificate);
        }
        setCvrNumber();
    }

    /**
     * Constructor that takes an oces certificate as parameter. If the
     * certificate is not an employee certificate an exception is thrown.
     *
     * @param certificate certificate
     * @throws MainException
     */
    public EmployeeOcesX509Certificate(OcesX509Certificate certificate) throws MainException {
        this(certificate.getCertificate());
    }

    /**
     * Gets the cvr number of the employee certificate.
     *
     * @return CVR number
     */
    public String getCvrNumber() {
        return cvrNumber;
    }

    /**
     * Extract CVR number.
     *
     * @throws MainException
     */
    private void setCvrNumber() throws MainException {
        String serialNumber = getSubject().getSerialNumberValue().toLowerCase();
        int cvrIndex = serialNumber.indexOf("cvr:");
        if (cvrIndex == -1) {
            throw new NoSubjectCvrNumberException(getCertificate());
        }
        if (serialNumber.indexOf("cvr:", cvrIndex + 1) != -1) {
            throw new AmbigousSubjectCvrNumberException(getCertificate());
        }
        int ix = serialNumber.indexOf("-", cvrIndex);
        cvrNumber = serialNumber.substring(cvrIndex + 4, ix);
    }
}