/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.security.oces;

import dk.gov.oiosi.exception.ArgumentNullException;

/**
 * Represents the configuration element to setup the subject key to the different certificates.
 */
public class OcesX509CertificateConfig
{
    private OcesCertificateSubjectKey _personalCertificateSubjectKey;
    private OcesCertificateSubjectKey _employeeCertificateSubjectKey;
    private OcesCertificateSubjectKey _organizationCertificateSubjectKey;
    private OcesCertificateSubjectKey _functionCertificateSubjectKey;

    /**
     * Default constructor used by XMLSerialization. It should not be used.
     */
    public OcesX509CertificateConfig() {
        _personalCertificateSubjectKey = new OcesCertificateSubjectKey();
        _employeeCertificateSubjectKey = new OcesCertificateSubjectKey();
        _organizationCertificateSubjectKey = new OcesCertificateSubjectKey();
        _functionCertificateSubjectKey = new OcesCertificateSubjectKey();
    }

	/**
     * Constructor that takes the subject key for each of the OCES certificate types.
     */
    public OcesX509CertificateConfig(OcesCertificateSubjectKey personalCertificateSubjectKey,
                                     OcesCertificateSubjectKey employeeCertificateSubjectKey,
                                     OcesCertificateSubjectKey organizationCertificateSubjectKey,
                                     OcesCertificateSubjectKey functionCertificateSubjectKey) {
        if (personalCertificateSubjectKey == null) throw new ArgumentNullException("personalCertificateSubjectKey");
        if (employeeCertificateSubjectKey == null) throw new ArgumentNullException("employeeCertificateSubjectKey");
        if (organizationCertificateSubjectKey == null) throw new ArgumentNullException("organizationCertificateSubjectKey");
        if (functionCertificateSubjectKey == null) throw new ArgumentNullException("functionCertificateSubjectKey");
        _personalCertificateSubjectKey = personalCertificateSubjectKey;
        _employeeCertificateSubjectKey = employeeCertificateSubjectKey;
        _organizationCertificateSubjectKey = organizationCertificateSubjectKey;
        _functionCertificateSubjectKey = functionCertificateSubjectKey;
    }

	public OcesCertificateSubjectKey get_personalCertificateSubjectKey() {
		return _personalCertificateSubjectKey;
	}

	public void set_personalCertificateSubjectKey(
			OcesCertificateSubjectKey certificateSubjectKey) {
		_personalCertificateSubjectKey = certificateSubjectKey;
	}

	public OcesCertificateSubjectKey get_employeeCertificateSubjectKey() {
		return _employeeCertificateSubjectKey;
	}

	public void set_employeeCertificateSubjectKey(
			OcesCertificateSubjectKey certificateSubjectKey) {
		_employeeCertificateSubjectKey = certificateSubjectKey;
	}

	public OcesCertificateSubjectKey get_organizationCertificateSubjectKey() {
		return _organizationCertificateSubjectKey;
	}

	public void set_organizationCertificateSubjectKey(
			OcesCertificateSubjectKey certificateSubjectKey) {
		_organizationCertificateSubjectKey = certificateSubjectKey;
	}

	public OcesCertificateSubjectKey get_functionCertificateSubjectKey() {
		return _functionCertificateSubjectKey;
	}

	public void set_functionCertificateSubjectKey(
			OcesCertificateSubjectKey certificateSubjectKey) {
		_functionCertificateSubjectKey = certificateSubjectKey;
	}
}
