/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.security.revocation;

import dk.gov.oiosi.common.RaspLibraryException;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Creates an instance of a class with the IRevocationLookup interface.
 */
public class RevocationLookupFactory {

    private static Log log = LogFactory.getLog(RevocationLookupFactory.class);

    private static IRevocationLookup lookupClient;

    /**
     * Builds an instance of an IRevocationLookup client based on configuration.
     *
     * @return revocation lookup
     */
    public static IRevocationLookup createRevocationLookupClient()  {
        if (lookupClient == null) {
            synchronized (RevocationLookupFactory.class) {
                RevocationLookupFactoryConfig config = ConfigurationHandler.getInstance().getRevocationLookupFactoryConfig();

                try {
                    log.debug("Init RevocationLookupFactory with class: " + config.getImplementationNamespaceClass());
                    lookupClient = (IRevocationLookup) Class.forName(config.getImplementationNamespaceClass()).newInstance();
                } catch (InstantiationException e) {
                    throw new RaspLibraryException(e);
                } catch (IllegalAccessException e) {
                    throw new RaspLibraryException(e);
                } catch (ClassNotFoundException e) {
                    throw new RaspLibraryException(e);
                }
            }
        }
        return lookupClient;
    }

    /**
     * Clears current singleton value, supposed to be used only in tests.
     *
     * @since OIORASP 1.3.0
     */
    protected static void clear() {
        lookupClient = null;
    }
}