/*
    Copyright 2010 DanID

    This file is part of OpenOcesAPI.

    OpenOcesAPI is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2.1 of the License, or
    (at your option) any later version.

    OpenOcesAPI is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with OpenOcesAPI; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


    Note to developers:
    If you add code to this file, please take a minute to add an additional
    @author statement below.
*/
package dk.gov.oiosi.security.revocation.ocsp;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;

import org.apache.log4j.Logger;

public class HttpClient {
    private static final Logger log = Logger.getLogger(HttpClient.class);

    public static byte[] doPostOCSPRequest(byte[] bs, String responderURL) throws Exception {
        try {
            HttpURLConnection conn = postRequest(bs, responderURL);

            if (conn.getResponseCode() != HttpURLConnection.HTTP_OK) {
                log.warn("http response code from OCSP request was: " + conn.getResponseCode());
                throw new Exception("http response code from OCSP request was: " + conn.getResponseCode());
            }

            int len = conn.getContentLength();

            byte[] respData = readResponse(conn, len);
            return respData;
        } catch (IOException e) {
            throw e;
        }
    }

    public static X509Certificate downloadCertificate(String location) {
		if (location == null) {
			throw new IllegalArgumentException("location is null");
		}
		if (!location.toLowerCase().startsWith("http://")) {
			throw new IllegalArgumentException("location excepted to have the prefix 'http://'");
		}
		try {
			URL url = new URL(location);
		    return X509CertificateFactory.getInstance().generateCertificate(url.openStream());
        } catch (IOException e) {
			throw new IllegalStateException(e);
		} catch (CertificateException e) {
            throw new IllegalStateException(e);
        }
    }

    private static HttpURLConnection postRequest(byte[] bs, String responderURL) throws IOException {
        HttpURLConnection conn = setupHttpConnectionForPost(bs.length, responderURL);
        OutputStream os = conn.getOutputStream();
        os.write(bs);
        conn.connect();
        os.close();
        return conn;
    }

    private static byte[] readResponse(HttpURLConnection conn, int len) throws IOException {
        InputStream is = conn.getInputStream();
        byte[] respData = new byte[len];
        int bRead = 0;

        do {
            bRead += is.read(respData, bRead, Math.min(1024, len - bRead));
        } while (bRead != len);

        is.close();
        conn.disconnect();
        return respData;
    }

    private static HttpURLConnection setupHttpConnectionForPost(int contentLength, String responderURL) throws IOException {
        HttpURLConnection conn;
        conn = (HttpURLConnection) new URL(responderURL).openConnection();
        conn.setAllowUserInteraction(false);
        conn.setDoInput(true);
        conn.setDoOutput(true);
        conn.setUseCaches(false);
        conn.setRequestMethod("POST");
        conn.setRequestProperty("Content-Length", "" + contentLength);
        conn.setRequestProperty("Content-Type", "application/ocsp-request");
        return conn;
    }
}
