/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.uddi;

import dk.gov.oiosi.exception.ArgumentNullException;
import dk.gov.oiosi.exception.NullOrEmptyArgumentException;

/**
 * Represents the process information in the UDDI structure.
 *
 * Note that the process information is deprecated and is now called the
 * process role definition.
 */
public class ProcessRoleDefinition {
    private String _name;
    private String _description;
    private String _role;
    private String _roleType;
    private UddiId _processDefinitionId;

    /**
     *  Constructor that takes the given parameters.
     */
    public ProcessRoleDefinition(String name, String description, String role, String roleType, UddiId processDefinitionId) {
        if (name == null || name.isEmpty()) throw new NullOrEmptyArgumentException("name");
        if (description == null) throw new ArgumentNullException("description");
        if (role == null) throw new ArgumentNullException("role");
        if (roleType == null) throw new ArgumentNullException("roleType");
        if (processDefinitionId == null) throw new ArgumentNullException("processDefinitionId");
        _name = name;
        _description = description;
        _role = role;
        _roleType = roleType;
        _processDefinitionId = processDefinitionId;
    }

    /**
     * Gets the name
     * @return
     */
	public String getName() {
		return _name;
	}

	/**
	 * Gets the description
	 * @return
	 */
	public String getDescription() {
		return _description;
	}

	/**
	 * Gets the role
	 * @return
	 */
	public String getRole() {
		return _role;
	}

	/**
	 * Gets the role type
	 * @return
	 */
	public String getRoleType() {
		return _roleType;
	}

	/**
	 * Gets the process definition id.
	 * @return
	 */
	public UddiId getProcessDefinitionId() {
		return _processDefinitionId;
	}

    @Override
    public String toString() {
        return "ProcessRoleDefinition{" +
                "_name='" + _name + '\'' +
                ", _description='" + _description + '\'' +
                ", _role='" + _role + '\'' +
                ", _roleType='" + _roleType + '\'' +
                ", _processDefinitionId=" + _processDefinitionId +
                '}';
    }
}
