/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and 
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.uddi;

import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.Collection;

import dk.gov.oiosi.communication.Uri;
import dk.gov.oiosi.exception.ArgumentNullException;

/**
 * Contains information about a specific registry. A registry can 
 * contain multiple endpoints which serves as fallbacks. 
 * @author dennis.soegaard
 */
public class Registry {
    private Collection<Uri> _endpoints = new ArrayList<Uri>();

    /**
     * Default constructor
     */
    public Registry(){}
    
    /**
     * Constructor that takes an array of endpoints.
     * @param endpoints An array of access points to this registry
     * @throws URISyntaxException 
     */
    public Registry(String[] endpoints) throws URISyntaxException {
    	if (endpoints == null) throw new ArgumentNullException("endpoints");
    	for (String endpoint : endpoints) {
    		_endpoints.add(new Uri(endpoint));
    	}
    }
    
    /**
     * Constructor that takes a list of endpoints.
     * @param endpoints A list of access points to this registry
     */
    public Registry(Collection<Uri> endpoints) {
    	if (endpoints == null) throw new ArgumentNullException("endpoints");
        _endpoints = endpoints;
    }


    /**
     * Gets the endpoints as a collection
     * @return The endpoint collection
     */
    public Collection<Uri> getEndpoints() {
    	return _endpoints;
    }
    
    /**
     * Sets the endpoints
     * @param endpoints The endpoints
     */
    public void setEndpoints(Collection<Uri> endpoints) {
    	if (endpoints == null) throw new ArgumentNullException("endpoints");
    	_endpoints = endpoints;
    }
    
}
