/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.uddi;

/**
 * UDDI configuration for the user.settings file.
 */
public class UddiConfig {
    private String _profileConformanceClaim = "";
    private String _registrationConformanceClaim = "";
    private String _publishEndpoint = "";
    private String _securityEndpoint = "";
    private int _fallbackTimeoutMinutes = 0;
    private LookupRegistryFallbackConfig _lookupRegistryFallbackConfig;
    
    /**
     * Default constructor
     */
    public UddiConfig() {}
    
	  /**
	  * Gets the default service profile claim used when performing a
	  * lookup
	  * @return ProfileConformanceClaim
	  */
	 public String getProfileConformanceClaim() {
	     return _profileConformanceClaim;
	 }
	
	 /**
	  * Sets the default service profile claim used when performing a
	  * lookup
	  * @param value ProfileConformanceClaim
	  */
	 public void setProfileConformanceClaim(String value) {
		 _profileConformanceClaim = value;
	 }
    
	   /**
	   * Gets the default UDDI profile claim used when performing a lookup
	   * @return RegistrationConformanceClaim
	   */
	  public String getRegistrationConformanceClaim() {
	      return _registrationConformanceClaim;
	  }
	
	  /**
	   * Sets the default UDDI profile claim used when performing a lookup
	   * @param value RegistrationConformanceClaim
	   */
	  public void setRegistrationConformanceClaim(String value) {
	      _registrationConformanceClaim = value;
	  }

	   /**
	    * Gets the default UDDI publish service endpoint
		* @return UddiPublishEndpointURL
		*/
	   public String getPublishEndpoint() {
	       return _publishEndpoint;
	   }
	
	   /**
	    * Sets the default UDDI publish service endpoint
	    * @param value UddiPublishEndpointURL
	    */
	   public void setPublishEndpoint(String value) {
	       _publishEndpoint = value;
	   }
	
	   /**
	    * Gets the default UDDI security endpoint
	    * @return UddiSecurityEndpointURL
	    */
	   public String getSecurityEndpoint() {
	       return _securityEndpoint;
	   }
	
	   /**
	    * Sets the default UDDI security endpoint
	    * @param value UddiSecurityEndpointURL
	    */
	   public void setSecurityEndpoint(String value) {
	       _securityEndpoint = value;
	   }

	   /**
	    * Gets the fallback timeout in minutes.
	    * @return fallbackTimeoutMinutes
	    */
	   public int getFallbackTimeoutMinutes() {
	       return _fallbackTimeoutMinutes;
	   }
	
	   /**
	    * Sets the fallback timeout in minutes.
	    * @param value fallbackTimeoutMinutes
	    */
	   public void setFallbackTimeoutMinutes(int value) {
	       _fallbackTimeoutMinutes = value;
	   }
	
	   /**
	    * Gets the lookup registration fallback configuration
	    * @return the lookup registration fallback configuration
	    */
	   public LookupRegistryFallbackConfig getLookupRegistryFallbackConfig() {
		   return _lookupRegistryFallbackConfig;
	   }

	   /**
	    * Sets the lookup registration fallback configuration
	    * @param lookupRegistryFallbackConfig the lookup registration fallback configuration
	    */
	   public void setLookupRegistryFallbackConfig(LookupRegistryFallbackConfig lookupRegistryFallbackConfig) {
		   _lookupRegistryFallbackConfig = lookupRegistryFallbackConfig;
	   }
}
