/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.uddi;

import dk.gov.oiosi.common.Guid;

/**
 * Represents a UDDI type guid.
 */
public class UddiGuidId extends UddiStringId {

    /**
     * Creates a new GUID
     */
    public UddiGuidId() {
        super();
    }

    /**
     * Constructs a new GUID class from an existing GUID string
     *
     * @param id         The guid as a string
     * @param isUddiType Whether or not the GUID has a uddi prefix
     */
    public UddiGuidId(String id, boolean isUddiType) {
        super(id, isUddiType);
    }

    /**
     * Constructs a uddi guid given an guid string. String must not have a "uddi:" prefix.
     *
     * @param guid The guid string
     */
    public UddiGuidId(String guid) throws UddiEmptyGuidException {
        super(guid, false);
    }

    /**
     * Constructs a uddi guid given a uddi id
     *
     * @param Id The UDDI id
     */
    public UddiGuidId(UddiId Id) {
        super(Id);
    }

    /**
     * Tests a guid to see if it is a valid uddi guid
     *
     * @param guid       guid to test
     * @param isUddiType indicates if it is a uddi type guid
     * @return Returns true if the guid is valid
     */
    public static boolean isValidGuidId(String guid, boolean isUddiType) {
        if (guid == null || guid.length() == 0) {
            return false;
        }

        String guidString = "";

        if (isUddiType) {
            if (guid.lastIndexOf(':') == -1) {
                return false;
            }
            guidString = guid.substring(guid.lastIndexOf(':') + 1);
        } else {
            guidString = guid;
        }

        return Guid.validateString(guidString);
    }

}