/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.uddi;

/**
 * Abstract base class for all UDDI v. 2.0 and 3.0 ID's, e.g.
 * "uddi:d01987d1-ab2e-3013-9be2-2a66eb99d824".
 */
public abstract class UddiId { // : IEquatable<UddiId> {

    /**
     * Abstract method for getting id
     */
    public abstract String getID();

    /**
     * Compares the two objects and returns true if they have equal values
     * 
     * Comparing is performed using the getID() method.
     * 
     * @param obj
     *            The object to compare to
     * @return Returns true if the two objects have identical values
     */
    @Override
    public final boolean equals(Object obj) {
		if (obj == null) return false;
		
		if (getClass() != obj.getClass()) return false;
		UddiId other = (UddiId) obj;
        
        return getID().equals(other.getID());
    }
    
    @Override
    public final int hashCode() {
    	return getID().hashCode();
    }
    
    @Override
    public String toString() {
    	return getID();
    }
}
