/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.uddi;

import java.lang.reflect.InvocationTargetException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import dk.gov.oiosi.common.RaspLibraryException;
import dk.gov.oiosi.communication.Uri;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.exception.MainException;
    
/** 
* Factory for creating IUddiLookup implementations
* 
 */
public class UddiLookupClientFactory {

    private static Log log = LogFactory.getLog(UddiLookupClientFactory.class);

    private static IUddiLookupClient lookupClient;
    
    private UddiLookupClientFactory() {}
    /** 
    * Creates an IUddiLookup implementation, as set in config.
    * 
    * @return The IUddiLookup implementation
    */
    public static IUddiLookupClient createUddiLookupClient() {

        synchronized ( UddiLookupClientFactory.class ) {
            if( lookupClient == null ) {
                UddiLookupClientFactoryConfig config = ConfigurationHandler.getInstance().getUddiLookupClientFactoryConfig();
                try {
                    log.debug("Init UddiLookupClientFactory : " + config.getImplementationNamespaceClass());
                    lookupClient = (IUddiLookupClient) Class.forName(config.getImplementationNamespaceClass()).newInstance();
                } catch (InstantiationException e) {
                    throw new RaspLibraryException(e);
                } catch (IllegalAccessException e) {
                    throw new RaspLibraryException(e);
                } catch (ClassNotFoundException e) {
                    throw new RaspLibraryException(e);
                }
            }
            return lookupClient;
        }

    }
    
    
    public static IUddiLookupClient createUddiLookupClient(Uri endpointAddress) throws MainException {
    	ConfigurationHandler handler = ConfigurationHandler.getInstance();
        UddiLookupClientFactoryConfig config = handler.getUddiLookupClientFactoryConfig();

        try {
            log.debug("Init UddiLookupClientFactory : " + config.getImplementationNamespaceClass());
            String implementingClass = config.getImplementationNamespaceClass();
            
            return (IUddiLookupClient) Class.forName(implementingClass).getConstructor(Uri.class).newInstance(endpointAddress);
        } catch (InstantiationException e) {
            throw new RaspLibraryException(e);
        } catch (IllegalAccessException e) {
            throw new RaspLibraryException(e);
        } catch (ClassNotFoundException e) {
            throw new RaspLibraryException(e);
        } catch (InvocationTargetException e) {
        	throw new RaspLibraryException(e);
        } catch (IllegalArgumentException e) {
			throw new RaspLibraryException(e);
		} catch (SecurityException e) {
			throw new RaspLibraryException(e);
		} catch (NoSuchMethodException e) {
			throw new RaspLibraryException(e);
		}
    }
}
