package dk.gov.oiosi.uddi;

import dk.gov.oiosi.common.Guid;
import dk.gov.oiosi.exception.NullOrEmptyArgumentException;
import dk.gov.oiosi.exception.UnexpectedNumberOfCharactersException;

/**
 * Simplefied uddi id type that uses a string representation.
 * This is a very lax implementation.
 */
public class UddiStringId extends UddiId {
    private String _noUddiPrefix;

	/**
	 * Creates a new Id
	 */
    public UddiStringId() {
        _noUddiPrefix = Guid.newGuid().toString();
    }

    /**
     * Creates a new Id given a text representation of the guid, and a boolean stating
     * whether it is prefixed with "uddi:".
     * @param id The guid
     * @param isUddiType whether it is prefixed with "uddi:".
     */
    public UddiStringId(String id, boolean isUddiType) {
        if (id == null || id.isEmpty()) throw new NullOrEmptyArgumentException("id");
        if (id.length() < 10) throw new UnexpectedNumberOfCharactersException("id", 10);
        if (isUddiType) {
            _noUddiPrefix = id.substring(5);
        } else {
            _noUddiPrefix = id;
        }
    }
    
    /**
     * Creates a new Uddi id
     * @param Id the id
     */
    public UddiStringId(UddiId Id) {
    	this(Id.toString(), true);
    }

    @Override
    public String getID() {
    	return "uddi:" + _noUddiPrefix;
    }

    @Override
    public String toString() {
        return getID();
    }
}
