package dk.gov.oiosi.util;

import javax.xml.namespace.QName;
import java.util.List;

/**
 * Simple utility class to work with Axis2 internal functionality.
 * <p/>
 * For now it contains only AxisFault related methods, used by client to provide
 * more details about fault reason code and fault action.
 *
 * @author Dmitriy Lapko, TrueLink A/S
 * @since OIORASP 1.3.0
 */
public class AxisUtil {

    /**
     * Extracts local parts from the list of fault codes, provided by AxisFault exception.
     *
     * @param faultSubCodes List of fault codes.
     * @return ";" delimited string with resolved fault actions, e.g.
     *         SchematronValidation or SchemaValidation etc.
     */
    public static String extractFaultAction(List<?> faultSubCodes) {
        if (faultSubCodes != null && !faultSubCodes.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            for (Object fsc : faultSubCodes) {
                if (fsc instanceof QName) {
                    QName qn = (QName) fsc;
                    if (sb.length() > 0) {
                        sb.append(";");
                    }
                    sb.append(qn.getLocalPart());
                }
            }
            return sb.toString();
        }
        return null;
    }

    /**
     * Extracts fault code from QName object. In OIORASP/Axis2 it is mostly
     * either "Receiver" or "Sender".
     *
     * @param faultCode faultCode
     * @return String with fault code
     */
    public static String extractFaultCode(QName faultCode) {
        if (faultCode != null) {
            return faultCode.getLocalPart();
        }
        return null;
    }
}