/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.xml.schema;

import dk.gov.oiosi.xml.XmlDocument;

/**
 * Custom exception used then schema validation fails.
 */
public class SchemaValidationFailedException extends SchemaValidationException {

    /**
     * serialVersionUID.
     */
    private static final long serialVersionUID = 2L;

    /**
     * Soap fault sub type / RASP fault action.
     */
    public static final String FAULT_ACTION = "SchemaValidationFault";

    /**
     * Constructor.
     *
     * @param document       the schema
     * @param innerException inner exception of the thrown exception
     */
    public SchemaValidationFailedException(final XmlDocument document, final Exception innerException) {
        super("Failed to validate document: " + innerException.getMessage());
        setReceiverError(false);
        setSoapFaultAction(FAULT_ACTION);
    }

    /**
     * Constructor.
     *
     * @param reason reason
     */
    public SchemaValidationFailedException(final String reason) {
        super(reason);
        setReceiverError(false);
        setSoapFaultAction(FAULT_ACTION);
    }
}