package dk.gov.oiosi.xml.xpath;

import org.apache.axiom.om.xpath.AXIOMXPath;
import org.apache.axiom.om.xpath.DocumentNavigator;
import org.jaxen.BaseXPath;
import org.jaxen.JaxenException;
import org.jaxen.NamedAccessNavigator;

/**
 * Usual {@link AXIOMXPath} uses {@link DocumentNavigator}, which does not
 * implement interface {@link NamedAccessNavigator}.
 *
 * Performance analysis shows, that in case of implementation of this interface,
 * XPaths are calculated faster.
 *
 * @author Dmitriy Lapko, TrueLink A/S
 *
 * @since OIORASP 1.3.0
 */
public class NamedAXIOMXPath extends BaseXPath {

	private static final long serialVersionUID = 8923559836828919225L;

	/**
	 * Construct an XPath expression from a given string.
	 *
	 * @param xpathExpr
	 *            the string representation of the XPath expression.
	 * @throws JaxenException
	 *             if there is a syntax error while parsing the expression
	 */
	public NamedAXIOMXPath(String xpathExpr) throws JaxenException {
		super(xpathExpr, new NamedOMDocumentNavigator());
	}

}
