/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.xml.xpath.discriminator;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

/**
 * A collection of XPath discriminator configurations.
 */
public final class XPathDiscriminatorConfigCollection {

    /**
     * List holding configs. List contains XPathDiscriminatorConfig
     */
    private List<XPathDiscriminatorConfig> xpathDiscriminatorConfigs;

    /**
     * Defatult constructor that initializes the collection.
     */
    public XPathDiscriminatorConfigCollection() {
        xpathDiscriminatorConfigs = new ArrayList<XPathDiscriminatorConfig>();
    }

    /**
     * Gets and sets the configurations of the collection.
     *
     * @return array of XPathDiscriminatorConfig
     */
    public XPathDiscriminatorConfig[] getXPathDiscriminatorConfigs() {
        return xpathDiscriminatorConfigs
                .toArray(new XPathDiscriminatorConfig[xpathDiscriminatorConfigs.size()]);
    }

    /**
     * Gets and sets the configurations of the collection.
     *
     * @param value the new collection
     */
    public void setXPathDiscriminatorConfigs(final XPathDiscriminatorConfig[] value) {
        xpathDiscriminatorConfigs = Arrays.asList(value);
    }

    /**
     * Adds an XPath discriminator configuration to the collection.
     *
     * @param xpathDiscriminatorConfig add to collection
     */
    public void add(final XPathDiscriminatorConfig xpathDiscriminatorConfig) {
        xpathDiscriminatorConfigs.add(xpathDiscriminatorConfig);
    }

    /**
     * Removes an XPath discriminator configuration from the collection.
     *
     * @param xpathDiscriminatorConfig remove from collection
     * @return true if removed
     */
    public boolean remove(final XPathDiscriminatorConfig xpathDiscriminatorConfig) {
        return xpathDiscriminatorConfigs.remove(xpathDiscriminatorConfig);
    }

    /**
     * Gets an IEnumerator to traverse the collection.
     *
     * @return iterator over XPathDiscriminatorConfig
     */
    public Iterator<XPathDiscriminatorConfig> getIterator() {
        return xpathDiscriminatorConfigs.iterator();
    }

    /**
     * Returns whether the collection is equal with another collection. This is
     * done by value comparering and not reference.
     *
     * @param other collection to compare with
     * @return true if equal
     */
    public boolean equals(final XPathDiscriminatorConfigCollection other) {
        if (other == null) {
            return false;
        }

        int thisCount = xpathDiscriminatorConfigs.size();
        int otherCount = other.xpathDiscriminatorConfigs.size();
        if (thisCount != otherCount) {
            return false;
        }

        for (XPathDiscriminatorConfig tmp : xpathDiscriminatorConfigs) {
            if (!other.xpathDiscriminatorConfigs.contains(tmp)) {
                return false;
            }
        }
        return true;
    }
}