package dk.gov.oiosi.common.cache.stat;

import dk.gov.oiosi.common.OutVariable;
import dk.gov.oiosi.common.cache.IThreadSafeCache;
import dk.gov.oiosi.configuration.CacheFactory;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.security.CertificateSubject;
import dk.gov.oiosi.security.revocation.crl.CrlInstance;
import dk.gov.oiosi.test.TestConstants;
import junit.framework.TestCase;
import org.apache.log4j.Level;

import java.net.URL;
import java.security.cert.CertificateFactory;

public class CacheStateLogScheduledJobTest extends TestCase {

    private static final boolean PRINT_STATES = false;

    protected void setUp() throws Exception {
        super.setUp();
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    @SuppressWarnings("unchecked")
    public void testBuildCacheListStateString() throws Exception {
        CacheStateLogScheduledJob j = new CacheStateLogScheduledJob();

        String state1 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state1);
        }
        assertNotNull(state1);

        CacheFactory.getInstance().getCertificateCache().add(new CertificateSubject("OID.2.5.4.5=CVR:33265735-FID:1293812813127 + CN=TL Nemhandel (funktionscertifikat), O=TRUELINK NEMHANDEL ApS // CVR:33265735, C=DK"), null);
        String state2 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state2);
        }
        assertTrue(!state1.equals(state2));

        URL url = new URL("http://blabla.dk");
        IThreadSafeCache<String, CrlInstance> crlCache = CacheFactory.getInstance().getCrlLookupCache();
        crlCache.containsKey(url.toExternalForm());
        state1 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state1);
        }
        assertTrue(!state1.equals(state2));

        crlCache.add(url.toExternalForm(), new CrlInstance(CertificateFactory.getInstance("X.509"), url));
        state2 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state2);
        }
        assertTrue(!state1.equals(state2));

        crlCache.checkExpired();
        state1 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state1);
        }
        assertTrue(!state1.equals(state2));

        crlCache.remove(url.toExternalForm());
        state2 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state2);
        }
        assertTrue(!state1.equals(state2));

        crlCache.set(url.toExternalForm(), new CrlInstance(CertificateFactory.getInstance("X.509"), url));
        state1 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state1);
        }
        assertTrue(!state1.equals(state2));

        crlCache.tryGetValue(url.toExternalForm(), new OutVariable<CrlInstance>());
        state2 = j.buildCacheListStateString();
        if (PRINT_STATES) {
            System.out.println(state2);
        }
        assertTrue(!state1.equals(state2));

        if (crlCache instanceof AbstractStatisticsCollectorCache) {
            assertEquals("tryGet(match/miss)=1/0 contains(match/miss)=0/1 remove/set/add=1/1/2 checkExpired(total/removedCount)=3/0", ((AbstractStatisticsCollectorCache<String, CrlInstance>) crlCache).getStatData().toString());
        }

        assertEquals("CacheStateLog", j.getJobDetails());
        assertNotNull(j.getLog());
        /*
           * With default level log
           */
        assertTrue(j.doJob());
        /*
           * With info level log
           */
        Level initLevel = j.getLog().getLevel();
        try {
            j.getLog().setLevel(Level.INFO);
            j.doJob();
        } finally {
            j.getLog().setLevel(initLevel);
        }
    }
}