package dk.gov.oiosi.common.startup;

import java.util.ArrayList;
import java.util.List;

import junit.framework.TestCase;
import dk.gov.oiosi.communication.configuration.DocumentTypeConfig;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;
import dk.gov.oiosi.xml.XmlDocument;
import dk.gov.oiosi.xml.documenttype.DocumentTypeConfigSearcher;
import dk.gov.oiosi.xml.schematron.SchematronValidator;

/**
 * Allows to compare performance improvements on first document validation in
 * case if schematron was preloaded or not.
 * 
 * Results: 
 * 
 * Preload schematron: false, schematron validation: 9512 ms
 * 
 * Preload schematron: true, schematron validation: 1842 ms
 * 
 * @author Dmitriy Lapko, TrueLink A/S
 * 
 */
public class SchematronPreloadStartupTaskSpeedTest extends TestCase {

	private static final boolean PRELOAD = true;

	protected void setUp() throws Exception {
		ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
	}

	public void testValidateSchematron() throws Exception {
		if (PRELOAD) {
			List<IStartupTask> list = new ArrayList<IStartupTask>(1);
			List<StartupTaskConfiguration> configList = new ArrayList<StartupTaskConfiguration>(1);
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_INIT_DOCUMENT_TYPE_FRIENDLY_NAME, "Faktura"));
			list.add(new SchematronPreloadStartupTask(configList));
			ConfigurationHandler handler = ConfigurationHandler.getInstance();
			handler.setStartupTaskList(list);
			handler.executeStartupTasks();
		}
		long start = System.currentTimeMillis();
		XmlDocument xd = new XmlDocument();
		xd.load(TestConstants.PATH_INVOICE);
		DocumentTypeConfigSearcher documentSearcher = new DocumentTypeConfigSearcher();
		DocumentTypeConfig documentType = documentSearcher.findUniqueDocumentType(xd);
		SchematronValidator sv = new SchematronValidator(documentType.getSchematronValidationConfig());
		sv.schematronValidateXmlDocument(xd);
		System.out.println("Preload schematron: " + PRELOAD + ", schematron validation: " + (System.currentTimeMillis() - start)+" ms");
	}
}
