package dk.gov.oiosi.common.startup;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Level;
import org.apache.log4j.Logger;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.exception.MainException;
import dk.gov.oiosi.test.TestConstants;
import junit.framework.TestCase;

public class SchematronPreloadStartupTaskTest extends TestCase {

	protected void setUp() throws Exception {
		ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
	}

	/*
	 * Check different configurations of the task and its logging
	 */
	public void testDoTask() throws MainException {
		/*
		 * Use Log4J for configuration of log level
		 */
		Logger logger = Logger.getLogger(AbstractStartupTask.LOG_NAME);
		Level initialLevel = logger.getLevel();
		
		try {
			logger.setLevel(Level.INFO);
			SchematronPreloadStartupTask t = new SchematronPreloadStartupTask();
			/*
			 * Empty case
			 */
			t.doTask();

			List<StartupTaskConfiguration> configList = new ArrayList<StartupTaskConfiguration>();
			/*
			 * Test config case
			 */
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_INIT_DOCUMENT_TYPE_FRIENDLY_NAME, "Faktura"));
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_INIT_DOCUMENT_TYPE_FRIENDLY_NAME, "Kreditnota"));
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_PREVALIDATE_XML_FOLDER, "Resources/Documents/Examples"));
			t.init(configList);
			t.doTask();
			
			configList.clear();
			/*
			 * Invalid configs case
			 */
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_INIT_DOCUMENT_TYPE_FRIENDLY_NAME, "Faktura Wrong name"));
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_INIT_DOCUMENT_TYPE_FRIENDLY_NAME, ""));
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_PREVALIDATE_XML_FOLDER, ""));
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_PREVALIDATE_XML_FOLDER, "Resources/Documents/Examples_Invalid"));
			configList.add(new StartupTaskConfiguration(SchematronPreloadStartupTask.CONFIG_PREVALIDATE_XML_FOLDER, "Invalid folder name"));
			
			t.doTask();
		} finally {
			/*
			 * Return back initial logging level
			 */
			logger.setLevel(initialLevel);
		}
	}
}
