package dk.gov.oiosi.configuration;

import dk.gov.oiosi.test.TestConstants;
import junit.framework.TestCase;

import java.util.HashMap;
import java.util.Map;

public class CacheConfigTest extends TestCase {

    private String zeroCacheNamespaceClass = "dk.gov.oiosi.common.cache.ZeroCache";
    private String quantityCacheNamespaceClass = "dk.gov.oiosi.common.cache.QuantityCache";
    private String timedCacheNamespaceClass = "dk.gov.oiosi.common.cache.TimedCache";
    private String assembly = "dk.gov.oiosi.RaspLibrary";

    @Override
    public void setUp() throws Exception {
        super.setUp();
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_PRODUCTION);
    }

    public void testOcspLookupCache() {
        CacheConfigElement element;
        boolean cacheCreated;

        // zeroCache
        Map<String, String> zeroCacheMap = new HashMap<String, String>();
        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.zeroCacheNamespaceClass, this.assembly, zeroCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // quantityCache
        Map<String, String> quantityCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("maxSize", "5");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.quantityCacheNamespaceClass, this.assembly, quantityCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // TimedCache
        Map<String, String> timedCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("timeInMinutes", "60");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.timedCacheNamespaceClass, this.assembly, timedCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);
    }

    public void testCrlLookupCache() {
        CacheConfigElement element;
        boolean cacheCreated;

        // zeroCache
        Map<String, String> zeroCacheMap = new HashMap<String, String>();
        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.zeroCacheNamespaceClass, this.assembly, zeroCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // quantityCache
        Map<String, String> quantityCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("maxSize", "5");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.quantityCacheNamespaceClass, this.assembly, quantityCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // TimedCache
        Map<String, String> timedCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("timeInMinutes", "60");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.timedCacheNamespaceClass, this.assembly, timedCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);
    }

    public void testUddiServiceCache() {
        CacheConfigElement element;
        boolean cacheCreated;

        // zeroCache
        Map<String, String> zeroCacheMap = new HashMap<String, String>();

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.zeroCacheNamespaceClass, this.assembly, zeroCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // quantityCache
        Map<String, String> quantityCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("maxSize", "5");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.quantityCacheNamespaceClass, this.assembly, quantityCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // TimedCache
        Map<String, String> timedCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("timeInMinutes", "60");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.timedCacheNamespaceClass, this.assembly, timedCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);
    }

    public void testUddiTModelCache() {
        CacheConfigElement element;
        boolean cacheCreated;

        // zeroCache
        Map<String, String> zeroCacheMap = new HashMap<String, String>();

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.zeroCacheNamespaceClass, this.assembly, zeroCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // quantityCache
        Map<String, String> quantityCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("maxSize", "5");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.quantityCacheNamespaceClass, this.assembly, quantityCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);

        // TimedCache
        Map<String, String> timedCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("timeInMinutes", "60");

        cacheCreated = false;
        try {
            // create the cache
            element = new CacheConfigElement(this.timedCacheNamespaceClass, this.assembly, timedCacheMap);
            CacheFactory.getInstance().createCache(element);
            cacheCreated = true;
        } catch (Exception ex) {
        }

        assertTrue("Cache not created", cacheCreated);
    }

    public void testCertificateCache() throws Exception {
        CacheConfigElement element;

        // zeroCache
        Map<String, String> zeroCacheMap = new HashMap<String, String>();

        // create the cache
        element = new CacheConfigElement(this.zeroCacheNamespaceClass, this.assembly, zeroCacheMap);
        assertNotNull("Cache not created", CacheFactory.getInstance().createCache(element));

        // quantityCache
        Map<String, String> quantityCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("maxSize", "5");

        // create the cache
        element = new CacheConfigElement(this.quantityCacheNamespaceClass, this.assembly, quantityCacheMap);
        assertNotNull("Cache not created", CacheFactory.getInstance().createCache(element));

        // TimedCache
        Map<String, String> timedCacheMap = new HashMap<String, String>();
        quantityCacheMap.put("timeInMinutes", "60");

        // create the cache
        element = new CacheConfigElement(this.timedCacheNamespaceClass, this.assembly, timedCacheMap);
        assertNotNull("Cache not created", CacheFactory.getInstance().createCache(element));
    }
}