package dk.gov.oiosi.configuration;

import java.io.File;
import java.io.IOException;

import org.apache.log4j.Logger;

import dk.gov.oiosi.test.TestConstants;
import junit.framework.TestCase;

public class ConfigurationLoaderUtilTest extends TestCase {

	public void testBuildLoadingErrorDescription() throws IOException {
		String s = ConfigurationLoaderUtil.buildLoadingErrorDescription(new String[] {"", "../"}, "RaspConfiguration.xml");
		System.out.println(s);
		File f = new File(".");
		String curFolder = f.getCanonicalPath();
		String curFolderParent = f.getAbsoluteFile().getParentFile().getParentFile().getCanonicalPath();
		assertEquals("Failed to locate OIORASP configuration file 'RaspConfiguration.xml', tried to check next locations: classpath, '" + curFolder + "\\RaspConfiguration.xml', '" + curFolderParent + "\\RaspConfiguration.xml'", s);
	}
	
	public void testLoadXMLConfiguration() {
		/*
		 * Check with null logger
		 */
		try {
			ConfigurationLoaderUtil.loadXMLConfiguration("RaspConfigUnavailable.xml", null);
			fail("Exception is expected");
		} catch (IllegalArgumentException e) {
		}
		/*
		 * Check with non null logger
		 */
		Logger logger = Logger.getLogger(ConfigurationLoaderUtilTest.class);
		assertNull(ConfigurationLoaderUtil.loadXMLConfiguration("RaspConfigUnavailable.xml", logger));
		
		/*
		 * Check damaged XML
		 */
		assertNull(ConfigurationLoaderUtil.loadXMLConfiguration(this.getClass().getName().replaceAll("\\.", "/")+"_Damaged_Rasp.xml", logger));
		
		assertNotNull(ConfigurationLoaderUtil.loadXMLConfiguration(TestConstants.PATH_RASPCONFIGURATION_PRODUCTION, logger));
		assertNotNull(ConfigurationLoaderUtil.loadXMLConfiguration(TestConstants.PATH_RASPCONFIGURATION_TEST, logger));
		assertNotNull(ConfigurationLoaderUtil.loadXMLConfiguration(ConfigurationHandlerTest.class.getName().replaceAll("\\.", "/")+"_RaspConfiguration_Old.xml", logger));
	}
}
