/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.security.ldap;

import dk.gov.oiosi.common.DateUtil;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.security.CertificateSubject;
import dk.gov.oiosi.security.lookup.CertificateLookupException;
import dk.gov.oiosi.security.validation.CertificateExpiredException;
import dk.gov.oiosi.security.validation.CertificateNotActiveException;
import dk.gov.oiosi.test.TestConstants;
import junit.framework.TestCase;

import java.math.BigInteger;
import java.security.cert.X509Certificate;

public class LdapCertificateLookupTest extends TestCase {

    private LdapCertificateLookup ldapCertificateLookup;

    @Override
    protected void setUp() throws Exception {
        super.setUp();

        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);

        LdapSettings ldapProdSettings = new LdapSettings();
//        ldapProdSettings.setHost("dir.certifikat.dk");
        ldapProdSettings.setHost("crtdir.certifikat.dk");
        ldapProdSettings.setPort(389);

        ldapCertificateLookup = new LdapCertificateLookup(ldapProdSettings);
    }

    public void testGetCertificate() throws Exception {
        String certSubject = "CN=Navision Stat (funktionscertifikat) + SERIALNUMBER=CVR:10213231-FID:1213785318933, O=Økonomistyrelsen // CVR:10213231, C=DK";
        X509Certificate result = ldapCertificateLookup.getCertificate(new CertificateSubject(certSubject));
//        System.err.println(result);
        assertEquals("Wrong cert. found...", BigInteger.valueOf(1170519605), result.getSerialNumber());
        assertEquals("Wrong cert. found...", "2012-05-31T10:40:13 UTC", DateUtil.formatDate(result.getNotBefore()));
    }

    public void testGetCertificate_nonExistingSubject() throws Exception {
        String certSubject = "CN=Y (funktionscertifikat) + OID.2.5.4.5=CVR:11111111-FID:2222222222222, O=X, C=DK";
        try {
            ldapCertificateLookup.getCertificate(new CertificateSubject(certSubject));
            fail("Exception not thrown - as expected");
        } catch (LdapCertificateNotFoundException e) {
            assertEquals("Exception changed", certSubject, e.getMessage());
        }
    }

    public void testWrongLdapServer() {
        LdapSettings setting = new LdapSettings();
        setting.setHost("localhost");
        LdapCertificateLookup ldapLookup = new LdapCertificateLookup(setting);
        try {
            CertificateSubject certSubject = new CertificateSubject(TestConstants.TEST_CERTIFICATE_SUBJECT_COMPANY);
            ldapLookup.getCertificate(certSubject);
            fail("This test should fail");
        } catch (ConnectingToLdapServerFailedException e) {
            // OK case!
        } catch (CertificateLookupException e) {
            fail("Wrong Exception" + e);
        } catch (CertificateNotActiveException e) {
            fail("Wrong Exception" + e);
        } catch (CertificateExpiredException e) {
            fail("Wrong Exception" + e);
        }
    }
}