/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.security.validation;

import java.security.cert.X509Certificate;

import junit.framework.TestCase;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.configuration.ConfigurationHandlerCleaner;
import dk.gov.oiosi.security.CertificateSubject;
import dk.gov.oiosi.security.ldap.LdapCertificateNotFoundException;
import dk.gov.oiosi.security.ldap.LdapLookupFactory;
import dk.gov.oiosi.security.lookup.ICertificateLookup;
import dk.gov.oiosi.test.TestConstants;

public class CertificateValidatorTest extends TestCase {

    @Override
    public void setUp() throws Exception {
        super.setUp();
        ConfigurationHandlerCleaner.clear();
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    public void testFunctionCertificate() throws Exception {
        assertCertificate(TestConstants.TEST_CERTIFICATE_SUBJECT_FUNCTION);
    }

    public void testCompanyCertificate() throws Exception {
        assertCertificate(TestConstants.TEST_CERTIFICATE_SUBJECT_COMPANY);
    }

    /**
     * Get company certificate.
     */
    public void testUnknownSubject() {
        // Subject DN, itst company certificate.
        String UNKNOWN_SUBJECTDN = "SERIALNUMBER=CVR:11111111-UID:1172691221366 + CN=IT- og Telestyrelsen - OIOSI test virksomhedssignatur, O=IT- og Telestyrelsen // CVR:26769388, C=DK";

        try {
            assertCertificate(UNKNOWN_SUBJECTDN);
            fail("This test should fail : " + UNKNOWN_SUBJECTDN);
        } catch (LdapCertificateNotFoundException e) {
            // Code should throw exception here!
        } catch (Exception e) {
            fail("Wrong Exception" + e);
        }
    }


    /**
     * Test getting certificate. Configuration comes from the configuration file.
     *
     * @param subjectString subject serial number
     * @throws Exception On error...
     */
    private void assertCertificate(String subjectString) throws Exception {
        ICertificateLookup ldapLookup = LdapLookupFactory.createLdapLookupClient();
        CertificateSubject certSubject = new CertificateSubject(subjectString);
        X509Certificate cert = ldapLookup.getCertificate(certSubject);
        assertNotNull("No cert. found based on input: " + subjectString);
        CertificateValidator.validateCertificate(cert);
    }
}