package dk.gov.oiosi.test.common;

import dk.gov.oiosi.addressing.*;
import dk.gov.oiosi.common.Utilities;
import dk.gov.oiosi.communication.configuration.DocumentTypeConfig;
import dk.gov.oiosi.communication.configuration.ProfileMappingCollectionConfig;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;
import dk.gov.oiosi.uddi.EndpointKeyTypeCode;
import dk.gov.oiosi.uddi.UddiId;
import dk.gov.oiosi.xml.XmlDocument;
import dk.gov.oiosi.xml.documenttype.DocumentTypeConfigSearcher;
import dk.gov.oiosi.xml.xpath.PrefixedNamespace;
import junit.framework.Assert;
import junit.framework.TestCase;

public class UtilitiesTest extends TestCase {

    private DocumentTypeConfigSearcher _searcher;

    @Override
    public void setUp() throws Exception {
        super.setUp();
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
        _searcher = new DocumentTypeConfigSearcher();
    }


    public void testProfileUddiIdCanBeResolvedFromValidOiosiMessage() throws Exception {
        ProfileMappingCollectionConfig profileMappingConfig = ConfigurationHandler.getInstance().getProfileMappingCollectionConfig();

        XmlDocument xmlDocument = new XmlDocument();
        xmlDocument.load(TestConstants.PATH_INVOICE);

        DocumentTypeConfigSearcher documentTypeSearcher = new DocumentTypeConfigSearcher();
        DocumentTypeConfig documentTypeConfig = documentTypeSearcher.findUniqueDocumentType(xmlDocument);

        UddiId profileUddiId = Utilities.getProfileId(xmlDocument, documentTypeConfig, profileMappingConfig);
        assertEquals("Wrong ProfileID found", "uddi:88FBD6D5-6A25-4c08-91CC-5344C73C4D69", profileUddiId.getID());
    }

    public void testIdentifierEAN() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_EAN);
        DocumentTypeConfig documentType = _searcher.findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(document, documentType);
        assertEquals(EndpointKeyTypeCode.ean, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey().getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document, keyXpath, namespaces, code);
        assertEquals(identifier.getClass(), IdentifierEan.class);
    }

    public void testIdentifierOVT() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_OVT);
        DocumentTypeConfig documentType = _searcher
                .findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(
                document, documentType);
        Assert.assertEquals(EndpointKeyTypeCode.ovt, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey()
                .getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document,
                keyXpath, namespaces, code);

        Assert.assertEquals(identifier.getClass(), IdentifierOvt.class);
    }

    public void testIdentifierCVR() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_CVR);
        DocumentTypeConfig documentType = _searcher
                .findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(
                document, documentType);
        Assert.assertEquals(EndpointKeyTypeCode.cvr, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey()
                .getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document,
                keyXpath, namespaces, code);

        Assert.assertEquals(identifier.getClass(), IdentifierCvr.class);
    }

    public void testIdentifierP() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_P);
        DocumentTypeConfig documentType = _searcher
                .findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(
                document, documentType);
        Assert.assertEquals(EndpointKeyTypeCode.p, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey()
                .getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document,
                keyXpath, namespaces, code);

        Assert.assertEquals(identifier.getClass(), IdentifierP.class);
    }

    public void testIdentifierSE() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_SE);
        DocumentTypeConfig documentType = _searcher
                .findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(
                document, documentType);
        Assert.assertEquals(EndpointKeyTypeCode.se, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey()
                .getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document,
                keyXpath, namespaces, code);

        Assert.assertEquals(identifier.getClass(), IdentifierSe.class);
    }

    public void testIdentifierVANS() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_VANS);
        DocumentTypeConfig documentType = _searcher
                .findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(
                document, documentType);
        Assert.assertEquals(EndpointKeyTypeCode.vans, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey()
                .getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document,
                keyXpath, namespaces, code);

        Assert.assertEquals(identifier.getClass(), IdentifierVans.class);
    }

    public void testIdentifierIBAN() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_IBAN);
        DocumentTypeConfig documentType = _searcher
                .findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(
                document, documentType);
        Assert.assertEquals(EndpointKeyTypeCode.iban, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey()
                .getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document,
                keyXpath, namespaces, code);

        Assert.assertEquals(identifier.getClass(), IdentifierIban.class);
    }

    public void testIdentifierDUNS() throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE_XML_IDENTIFIER_DUNS);
        DocumentTypeConfig documentType = _searcher
                .findUniqueDocumentType(document);
        EndpointKeyTypeCode code = Utilities.getEndpointKeyTypeCode(
                document, documentType);
        Assert.assertEquals(EndpointKeyTypeCode.duns, code.getCode());

        String keyXpath = documentType.getEndpointType().getKey()
                .getXPath();
        PrefixedNamespace[] namespaces = documentType.getNamespaces();

        Identifier identifier = Utilities.getEndpointKeyByXpath(document,
                keyXpath, namespaces, code);

        Assert.assertEquals(identifier.getClass(), IdentifierDuns.class);
    }
}