package dk.gov.oiosi.test.unit.common.cache;

import dk.gov.oiosi.common.OutVariable;
import dk.gov.oiosi.common.cache.ICache;
import dk.gov.oiosi.common.cache.QuantityCache;
import junit.framework.Assert;
import junit.framework.TestCase;

@SuppressWarnings("deprecation")
public class QuantityCacheTest extends TestCase {

    protected ICache<String, String> _cache;

	protected ICache<String, String> buildCache(int maxSize) {
		return new QuantityCache<String, String>(maxSize);
	}
    
    public void testSingleAddRemove() {
        System.out.println("Single Add Remove Test Started");

        _cache = buildCache(4);
        _cache.add("test", "test");
        assertCacheContainsKey("test");
        _cache.remove("test");
        testDoNotExists("test");
    }

    public void testMultipleAddRemove() {
        System.out.println("Multiple Add Remove Test Stated");

        _cache = buildCache(6);
        String[] a = new String[]{"a1", "a2", "a3"};
        String[] b = new String[]{"b1", "b2"};
        String[] c = new String[]{"c1", "c2", "c3"};

        addStrings(a);
        addStrings(b);
        checkStringsExists(a);
        checkStringsExists(b);

        removeStrings(b);
        checkStringsExists(a);
        checkStringsNotExists(b);

        addStrings(c);
        checkStringsExists(a);
        checkStringsExists(c);

        System.out.println("Multiple Add Remove Test Completed");
    }

    public void testMultipleAddAboveLimit() {
        System.out.println("Multiple Add Above Limit Test Stated");

        _cache = buildCache(5);
        String[] a = new String[]{"a1", "a2", "a3"};
        String[] b = new String[]{"b1", "b2"};
        String[] c = new String[]{"c1", "c2", "c3"};

        addStrings(a);
        addStrings(b);
        checkStringsExists(a);
        checkStringsExists(b);

        addStrings(c);
        checkStringsExists(b);
        checkStringsExists(c);
        checkStringsNotExists(a);

        System.out.println("Multiple Add Above Limit Test Completed");
    }

    public void testMultipleAddAboveLimitLastViewed() {
        System.out.println("Multiple Add Above Limit Last Viewed Test Stated");

        _cache = buildCache(4);
        String[] a = new String[]{"a1", "a2"};
        String[] b = new String[]{"b1", "b2"};
        String[] c = new String[]{"c1", "c2"};

        addStrings(a);
        addStrings(b);
        checkStringsExists(b);
        checkStringsExists(a);

        addStrings(c);
        checkStringsExists(a);
        checkStringsExists(c);
        checkStringsNotExists(b);
    }

    private void addStrings(String[] strings) {
        for (String s : strings) {
            testAdd(s, s);
        }
    }

    private void removeStrings(String[] strings) {
        for (String s : strings) {
            testRemove(s);
        }
    }

    private void checkStringsExists(String[] strings) {
        for (String s : strings) {
            assertCacheContainsKey(s);
        }
    }

    private void checkStringsNotExists(String[] strings) {
        for (String s : strings) {
            testDoNotExists(s);
        }
    }

    private void testAdd(String key, String value) {
        _cache.add(key, value);
        assertCacheContainsKey(key);
        testElement(key, value);
    }

    private void testRemove(String key) {
        _cache.remove(key);
        testDoNotExists(key);
    }

    private void assertCacheContainsKey(String key) {
        assertTrue(_cache.containsKey(key));
        OutVariable<String> current = new OutVariable<String>();
        assertTrue(_cache.tryGetValue(key, current));
    }

    private void testElement(String key, String expected) {
        OutVariable<String> current = new OutVariable<String>();
        assertTrue(_cache.tryGetValue(key, current));
        assertEquals("Wrong value from on key=" + key, expected, current.getVariable());
    }

    private void testDoNotExists(String key) {
        Assert.assertFalse(_cache.containsKey(key));
        OutVariable<String> current = new OutVariable<String>();
        Assert.assertFalse(_cache.tryGetValue(key, current));
    }
}
