/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.unit.communication.configuration;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import dk.gov.oiosi.common.Guid;
import dk.gov.oiosi.communication.configuration.DocumentTypeConfig;
import dk.gov.oiosi.xml.xpath.discriminator.XPathDiscriminatorConfig;
import dk.gov.oiosi.xml.xpath.discriminator.XPathDiscriminatorConfigCollection;
import junit.framework.TestCase;

/**
 * Test documnet type config.
 */
public class DocumentTypeConfigTest extends TestCase {

    /**
     * local log.
     */
    private static Log log = LogFactory.getLog(DocumentTypeConfigTest.class);

    /**
     * document equal by id.
     */
    public void test_02_DocumentTypeEqualsOnIdTest() {
        try {
            log.info("_02_SimpleDocumentTypeEqualsOnIdTest");
            DocumentTypeConfig a = new DocumentTypeConfig();
            DocumentTypeConfig b = new DocumentTypeConfig();
            Guid id = Guid.newGuid();
            a.setId(id);
            b.setId(id);
            a.setRootName("TestA");
            b.setRootName("TestB");
            assertTrue(a.equals(b));
            log.info("_02_ OK");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            fail(e.getMessage());
        }
    }

    /**
     * documents equals by parameters.
     */
    public void test_03_DocumentTypeEqualsOnParameters() {
        try {
            log.info("_03_SimpleDocumentTypeEqualsOnParameters");
            String rootName = "Test";
            String rootNamespace = "http://oio.dk/test";
            XPathDiscriminatorConfig identifierDiscriminatorA = new XPathDiscriminatorConfig("//Test/Key", "A");
            XPathDiscriminatorConfig identifierDiscriminatorB = new XPathDiscriminatorConfig("//Test/Key", "B");
            XPathDiscriminatorConfigCollection identifierDiscriminators = new XPathDiscriminatorConfigCollection();
            identifierDiscriminators.add(identifierDiscriminatorA);
            identifierDiscriminators.add(identifierDiscriminatorB);
            DocumentTypeConfig a = new DocumentTypeConfig(rootName, rootNamespace, identifierDiscriminators);
            DocumentTypeConfig b = new DocumentTypeConfig(rootName, rootNamespace, identifierDiscriminators);
            assertTrue(a.equals(b));
            log.info("_03_ OK");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            fail(e.getMessage());
        }
    }

    /**
     * document should match regardless of discriminator ordering.
     */
    public void test_04_DocumentTypeEqualsOnParametersDifferentOrderingOfDiscriminators() {
        try {
            log.info("_04_DocumentTypeEqualsOnParametersDifferentOrderingOfDiscriminators");
            String rootName = "Test";
            String rootNamespace = "http://oio.dk/test";
            XPathDiscriminatorConfig identifierDiscriminatorA = new XPathDiscriminatorConfig("//Test/Key", "A");
            XPathDiscriminatorConfig identifierDiscriminatorB = new XPathDiscriminatorConfig("//Test/Key", "B");
            XPathDiscriminatorConfigCollection identifierDiscriminatorsA = new XPathDiscriminatorConfigCollection();
            identifierDiscriminatorsA.add(identifierDiscriminatorA);
            identifierDiscriminatorsA.add(identifierDiscriminatorB);
            XPathDiscriminatorConfigCollection identifierDiscriminatorsB = new XPathDiscriminatorConfigCollection();
            identifierDiscriminatorsB.add(identifierDiscriminatorB);
            identifierDiscriminatorsB.add(identifierDiscriminatorA);
            DocumentTypeConfig a = new DocumentTypeConfig(rootName, rootNamespace, identifierDiscriminatorsA);
            DocumentTypeConfig b = new DocumentTypeConfig(rootName, rootNamespace, identifierDiscriminatorsB);
            assertTrue(a.equals(b));
            log.info("_04_ OK");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            fail(e.getMessage());
        }
    }

    /**
     * document should not match.
     */
    public void test_05_DocumentTypeNotEqualRootNameAndId() {
        try {
            log.info("_05_DocumentTypeNotEqualRootNameAndId");
            String rootNameA = "TestA";
            String rootNameB = "TestB";
            String rootNamespace = "http://oio.dk/test";
            XPathDiscriminatorConfig identifierDiscriminatorA = new XPathDiscriminatorConfig("//Test/Key", "A");
            XPathDiscriminatorConfig identifierDiscriminatorB = new XPathDiscriminatorConfig("//Test/Key", "B");
            XPathDiscriminatorConfigCollection identifierDiscriminators = new XPathDiscriminatorConfigCollection();
            identifierDiscriminators.add(identifierDiscriminatorA);
            identifierDiscriminators.add(identifierDiscriminatorB);
            DocumentTypeConfig a = new DocumentTypeConfig(rootNameA, rootNamespace, identifierDiscriminators);
            DocumentTypeConfig b = new DocumentTypeConfig(rootNameB, rootNamespace, identifierDiscriminators);
            assertFalse(a.equals(b));
            log.info("_05_ OK");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            fail(e.getMessage());
        }
    }

    /**
     * document should not match.
     */
    public void test_06_DocumentTypeNotEqualRootNamespaceAndId() {
        try {
            log.info("_06_DocumentTypeNotEqualRootNamespaceAndId");
            String rootName = "Test";
            String rootNamespaceA = "http://oio.dk/testA";
            String rootNamespaceB = "http://oio.dk/testB";
            XPathDiscriminatorConfig identifierDiscriminatorA = new XPathDiscriminatorConfig("//Test/Key", "A");
            XPathDiscriminatorConfig identifierDiscriminatorB = new XPathDiscriminatorConfig("//Test/Key", "B");
            XPathDiscriminatorConfigCollection identifierDiscriminators = new XPathDiscriminatorConfigCollection();
            identifierDiscriminators.add(identifierDiscriminatorA);
            identifierDiscriminators.add(identifierDiscriminatorB);
            DocumentTypeConfig a = new DocumentTypeConfig(rootName, rootNamespaceA, identifierDiscriminators);
            DocumentTypeConfig b = new DocumentTypeConfig(rootName, rootNamespaceB, identifierDiscriminators);
            assertFalse(a.equals(b));
            log.info("_06_ OK");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            fail(e.getMessage());
        }
    }

    /**
     * document should not match.
     */
    public void test_07_DocumentTypeNotEqualIndentifierDiscriminatorsAndId() {
        try {
            log.info("_07_DocumentTypeNotEqualIndentifierDiscriminatorsAndId");
            String rootName = "Test";
            String rootNamespace = "http://oio.dk/test";
            XPathDiscriminatorConfig identifierDiscriminatorA = new XPathDiscriminatorConfig("//Test/Key", "A");
            XPathDiscriminatorConfig identifierDiscriminatorB = new XPathDiscriminatorConfig("//Test/Key", "B");
            XPathDiscriminatorConfig identifierDiscriminatorC = new XPathDiscriminatorConfig("//Test/Key", "C");
            XPathDiscriminatorConfigCollection identifierDiscriminatorsA = new XPathDiscriminatorConfigCollection();
            identifierDiscriminatorsA.add(identifierDiscriminatorA);
            identifierDiscriminatorsA.add(identifierDiscriminatorB);
            XPathDiscriminatorConfigCollection identifierDiscriminatorsB = new XPathDiscriminatorConfigCollection();
            identifierDiscriminatorsB.add(identifierDiscriminatorB);
            identifierDiscriminatorsB.add(identifierDiscriminatorC);
            DocumentTypeConfig a = new DocumentTypeConfig(rootName, rootNamespace, identifierDiscriminatorsA);
            DocumentTypeConfig b = new DocumentTypeConfig(rootName, rootNamespace, identifierDiscriminatorsB);
            assertFalse(a.equals(b));
            log.info("_07_ OK");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            fail(e.getMessage());
        }
    }

}
