/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.unit.security;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.security.validation.CertificateExpiredException;
import dk.gov.oiosi.security.validation.CertificateNotActiveException;
import dk.gov.oiosi.security.validation.CertificateValidator;
import dk.gov.oiosi.test.TestConstants;
import junit.framework.TestCase;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;

public class ValidateCertificateTest extends TestCase {

    @Override
    protected void setUp() throws Exception {
        super.setUp();

        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    // TODO: Add negative tests!

    /**
     * test ocsp for expired certificate.
     */
    public void testExpired() throws Exception {
        X509Certificate cert = getCertificate("server_tdc_expired");
        assertNotNull("Certificate not found", cert);
        try {
            CertificateValidator.validateCertificate(cert);
            fail("Expected expired, but was ok");
        } catch (CertificateNotActiveException e) {
            fail("Expected expired, but was not yet active " + e);
        } catch (CertificateExpiredException e) {
            // Success!
        }
    }

    /**
     * Test ocsp for valid certificate.
     *
     * @throws FileNotFoundException On error...
     * @throws CertificateException  On error...
     */
    public void testValid() throws Exception {
        InputStream inStream = new FileInputStream(TestConstants.PATH_FOCES1_VALID);
        CertificateFactory cf = CertificateFactory.getInstance("X.509");
        X509Certificate cert = (X509Certificate) cf.generateCertificate(inStream);
        assertNotNull("No certificate", cert);
        CertificateValidator.validateCertificate(cert);
    }

    /**
     * Read certificate from keystore.
     */
    protected X509Certificate getCertificate(String keyLabel) throws Exception {
        KeyStore ks = KeyStore.getInstance("JKS");
        ks.load(new FileInputStream(TestConstants.PATH_KEYSTORE_TEST), TestConstants.PASSWORD_KEYSTORE_TEST.toCharArray());

        return (X509Certificate) ks.getCertificate(keyLabel);
    }
}