package dk.gov.oiosi.test.unit.uddi;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import dk.gov.oiosi.addressing.EndpointAddress;
import dk.gov.oiosi.addressing.EndpointAddressHttp;
import dk.gov.oiosi.addressing.Identifier;
import dk.gov.oiosi.common.Version;
import dk.gov.oiosi.communication.Uri;
import dk.gov.oiosi.exception.MainException;
import dk.gov.oiosi.security.CertificateSubject;
import dk.gov.oiosi.uddi.IUddiLookupClient;
import dk.gov.oiosi.uddi.LookupParameters;
import dk.gov.oiosi.uddi.ProcessDefinition;
import dk.gov.oiosi.uddi.UddiException;
import dk.gov.oiosi.uddi.UddiId;
import dk.gov.oiosi.uddi.UddiLookupResponse;
import dk.gov.oiosi.uddi.ProcessRoleDefinition;

public class AdvancedUddiDummyClient implements IUddiLookupClient {
	private AdvancedUddiDummyClientConfig configuration;
	private Uri _address;

	public AdvancedUddiDummyClient(Uri address){
		_address = address;
		this.configuration = AdvancedUddiDummyClientConfig.getInstance();
	}

	public AdvancedUddiDummyClientConfig getAdvancedUddiDummyClientConfig() {
		return configuration;
	}
	
	public void setAdvancedUddiDummyClientConfig(AdvancedUddiDummyClientConfig configuration) {
		this.configuration = configuration;
	}
	

    public List<UddiLookupResponse> lookup(LookupParameters parameters) throws MainException {
    	if (configuration._erroneousEndpoints.contains(_address)) {
    		System.out.println("Dummy UDDI throwing on register " + _address);
    		throw new UddiException(parameters.getIdentifier().getAsString(), new Exception("Error error"));
    	}
    	if (configuration.getNonExistingRegistrations().containsKey(_address) && configuration.getNonExistingRegistrations().get(_address).contains(parameters.getIdentifier())) {
    		System.out.println("Dummy UDDI returning empty from register " + _address);
    		return new ArrayList<UddiLookupResponse>();
    	}
		System.out.println("Dummy UDDI returning " + parameters.getIdentifier().getAsString() + " from " + _address);
		ArrayList<UddiLookupResponse> responses = new ArrayList<UddiLookupResponse>();
		Identifier endpointIdentifierActual = parameters.getIdentifier();
		EndpointAddress endpointAddress = new EndpointAddressHttp(_address);
		Calendar calendar = Calendar.getInstance();
		calendar.set(2006, 9, 01, 8, 30);
		Date activationDate = calendar.getTime();
		calendar.set(2056, 9, 01, 8, 30);
		Date expirationDate = calendar.getTime();
		CertificateSubject subject = new CertificateSubject("SERIALNUMBER=CVR:25767535-UID:1100080130597 + CN=TDC TOTALLØSNINGER A/S - TDC Test, O=TDC TOTALLØSNINGER A/S // CVR:25767535, C=DK");
		Version version = new Version("1.0.0");
		List<ProcessRoleDefinition> processesRoles = new ArrayList<ProcessRoleDefinition>();
		UddiLookupResponse response = new UddiLookupResponse(endpointIdentifierActual, endpointAddress, activationDate, expirationDate, subject, null, null, version, null, processesRoles);
		responses.add(response);
		return responses;
    }
    
	@Override
	public List<ProcessDefinition> GetProcessDefinitions(
			List<UddiId> processDefinitionIds) throws MainException {
		// Currently this is not used in tests
		return null;
	}
	
    public static class AdvancedUddiDummyClientConfig {
        private List<Uri> _erroneousEndpoints = new ArrayList<Uri>();
        private Map<Uri, List<Identifier>> _nonExistingRegistrations = new HashMap<Uri, List<Identifier>>();
        private static AdvancedUddiDummyClientConfig _instance = null;
        private static Object _lock = new Object(); 
        
        public AdvancedUddiDummyClientConfig() {
        	System.out.println("AdvancedUddiDummyClientConfig()");
        }
        
        public static AdvancedUddiDummyClientConfig getInstance() {
        	synchronized (_lock) {
        		if (_instance == null) {
        			_instance = new AdvancedUddiDummyClientConfig();
        		}
        		return _instance;
			}
        }
        
        
        public List<Uri> getErroneousEndpoints() {
        	return _erroneousEndpoints; 
        }

        public void setErroneousEndpoints(List<Uri> erroneousEndpoints) {
        	_erroneousEndpoints = erroneousEndpoints; 
        }

        public Map<Uri, List<Identifier>> getNonExistingRegistrations() {
            return _nonExistingRegistrations;
        }
        
        public void setNonExistingRegistrations(Map<Uri, List<Identifier>> NonExistingRegistrations) {
            _nonExistingRegistrations = NonExistingRegistrations;
        }
    }
}
