package dk.gov.oiosi.test.unit.uddi;

import dk.gov.oiosi.uddi.UddiGuidId;
import dk.gov.oiosi.uddi.UddiNonGuidId;
import junit.framework.Assert;
import junit.framework.TestCase;
import org.junit.Test;


public class UddiGuidIDTest extends TestCase {

    @Test
    public void testCheckUddiGuidValidWithoutUddi() {
        Assert.assertFalse(UddiGuidId.isValidGuidId("uddi:4ba19475-2b75-452c-969c-fdeb5f07739e", false));
        Assert.assertTrue(UddiGuidId.isValidGuidId("4ba19475-2b75-452c-969c-fdeb5f07739e", false));
    }

    @Test
    public void testCheckUddiGuidValidWithUddi() {
        boolean notValid = UddiGuidId.isValidGuidId("4ba19475-2b75-452c-969c-fdeb5f07739e", true);
        boolean valid = UddiGuidId.isValidGuidId("uddi:4ba19475-2b75-452c-969c-fdeb5f07739e", true);
        Assert.assertFalse(notValid);
        Assert.assertTrue(valid);
    }

    @Test
    public void testCheckUddiGuidValidWithNemHandel() {
        boolean notValid = UddiGuidId.isValidGuidId("4ba19475-2b75-452c-969c-fdeb5f07739e", true);
        boolean valid = UddiGuidId.isValidGuidId("uddi:nemhandel.dk:4ba19475-2b75-452c-969c-fdeb5f07739e", true);
        Assert.assertFalse(notValid);
        Assert.assertTrue(valid);
    }

    @Test
    public void testCheckNonUddiGuidWithoutUddi() {
        try {
            new UddiNonGuidId("4ba19475-2b75-452c-969c-fdeb5f07739e");
        } catch (IllegalArgumentException e) {
            return;
        }
        fail("Expected IllegalArgumentException");
    }

    @Test(expected = IllegalArgumentException.class)
    public void testCheckNonUddiGuidWithUddi() {
        try {
            new UddiNonGuidId("uddi:4ba19475-2b75-452c-969c-fdeb5f07739e");
        } catch (IllegalArgumentException e) {
            return;
        }
        fail("Expected IllegalArgumentException");
    }

    @Test
    public void testCheckNonUddiGuid() {
        try {
            new UddiNonGuidId("uddi:4ba19475-2b75-452c-969c-fdeb5f07739e111111");
        } catch (IllegalArgumentException e) {
            Assert.fail();
        }
    }
}