/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.unit.xml.schematron;

import dk.gov.oiosi.TestUtil;
import dk.gov.oiosi.communication.configuration.DocumentTypeConfig;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;
import dk.gov.oiosi.xml.XmlDocument;
import dk.gov.oiosi.xml.documenttype.DocumentTypeConfigSearcher;
import dk.gov.oiosi.xml.schematron.SchematronErrorException;
import dk.gov.oiosi.xml.schematron.SchematronValidationConfig;
import dk.gov.oiosi.xml.schematron.SchematronValidator;
import junit.framework.TestCase;

import java.io.File;

/**
 * Runs a schematron validation on all document types.
 */
public class SchematronValidationTest extends TestCase {

    @Override
    public void setUp() throws Exception {
        super.setUp();
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    /**
     * Verify that the TestConstants have the right COMMON_PATH.
     */
    public void testTestConstantsPaths() {
        File file = new File(TestConstants.PATH_APPLICATIONRESPONSE_201);
        assertTrue("File not found on path", file.exists());
    }

    public void testOioublApplicationResponseValidation() throws Exception {
        validate(TestConstants.PATH_APPLICATIONRESPONSE_201);
    }

    public void testOioublCatalogueValidation() throws Exception {
        validate(TestConstants.PATH_CATALOGUE);
    }

    public void testOioublCatalogueDeletionValidation() throws Exception {
        validate(TestConstants.PATH_CATALOGUEDELETION);
    }

    public void testOioublCatalogueItemSpecificationUpdateValidation() throws Exception {
        validate(TestConstants.PATH_CATALOGUEITEMSPECIFICATIONUPDATE);
    }

    public void testOioublCataloguePricingUpdateValidation() throws Exception {
        validate(TestConstants.PATH_CATALOGUEPRICINGUPDATE);
    }

    public void testOioublCatalogueRequestValidation() throws Exception {
        validate(TestConstants.PATH_CATALOGUEREQUEST);
    }

    public void testOioublCreditNoteValidation() throws Exception {
        validate(TestConstants.PATH_CREDITNOTE);
    }

    public void testOioublInvoiceValidation() throws Exception {
        validate(TestConstants.PATH_INVOICE);
    }

    public void testOioublOrderValidation() throws Exception {
        validate(TestConstants.PATH_ORDER);
    }

    public void testOioublOrderCancellationValidation() throws Exception {
        validate(TestConstants.PATH_ORDERCANCELLATION);
    }

    public void testOioublOrderChangeValidation() throws Exception {
        validate(TestConstants.PATH_ORDERCHANGE);
    }

    public void testOioublOrderResponseValidation() throws Exception {
        validate(TestConstants.PATH_ORDERRESPONSE);
    }

    public void testOioublOrderResponseSimpleValidation() throws Exception {
        validate(TestConstants.PATH_ORDERRESPONSESIMPLE);
    }

    public void testOioublReminderValidation() throws Exception {
        validate(TestConstants.PATH_REMINDER);
    }

    public void testOioublStatementValidation() throws Exception {
        validate(TestConstants.PATH_STATEMENT);
    }

    public void testOioublUtilityStatementValidation() throws Exception {
        validate(TestConstants.PATH_UTILITYSTATEMENT_XML);
    }

    public void testOioxmlInvoiceValidation07() throws Exception {
        validate(TestConstants.PATH_INVOICE_PIE);
    }

    public void testOioxmlCreditNoteValidation07() throws Exception {
        validate(TestConstants.PATH_CREDITNOTE07_XML);
    }

    public void testOioublNoIdInvoiceValidation() throws Exception {
        try {
            validate(TestConstants.PATH_INVOICE_NO_ID);
            fail("testOioublNoIdInvoiceValidation should fail");
        } catch (SchematronErrorException e) {
            assertTrue(true);
        }
    }

    public void testOioxmlInvalidEanNumberInvoiceValidation() throws Exception {
        try {
            validate(TestConstants.PATH_INVOICE_INVALID_EAN_NUMBER);
            fail("testOioxmlInvalidEanNumberInvoiceValidation should give error");
        } catch (SchematronErrorException e) {
            assertTrue(true);
        }
    }

    /**
     * Verify that it's possible to schematron validate all the example files located in "Resources\Documents\Examples".
     */
    public void testSchematronValidateAllTestFiles() {
        for (File file : TestUtil.getOkExampleDocumentPaths()) {
            try {
                validate(file.getAbsolutePath());
            } catch (Exception e) {
                fail("Unable to Schematron validate document [" + TestConstants.PATH_EXAMPLES_OK + file.getName() + "]: " + e.getMessage());
            }
        }
    }

    /**
     * Perform validation.
     *
     * @param xmlDocumentPath Path to document to validate.
     * @throws Exception On error...
     */
    private void validate(String xmlDocumentPath) throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(xmlDocumentPath);

        DocumentTypeConfigSearcher docSearcher = new DocumentTypeConfigSearcher();
        DocumentTypeConfig documentType = docSearcher.findUniqueDocumentType(document);
        SchematronValidationConfig schematronValidationConfig = documentType.getSchematronValidationConfig();
        SchematronValidator validator = new SchematronValidator(schematronValidationConfig);
        validator.schematronValidateXmlDocument(document);
    }
}