/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.unit.xml.xpath;

import dk.gov.oiosi.addressing.Identifier;
import dk.gov.oiosi.common.Utilities;
import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;
import dk.gov.oiosi.uddi.EndpointKeyTypeCode;
import dk.gov.oiosi.xml.XmlDocument;
import dk.gov.oiosi.xml.documenttype.DocumentTypeConfigSearcher;
import dk.gov.oiosi.xml.xpath.PrefixedNamespace;
import junit.framework.TestCase;

import java.util.Hashtable;

/**
 * Read identifier from all documents types (using xpath from config) and compare with fixed identifier.
 */
public class IdentifierXPathTest extends TestCase {

    @Override
    public void setUp() throws Exception {
        super.setUp();
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    public void testIdentifiersReadFromXPathExpression() throws Exception {
        Hashtable<String, String> dictionary = new Hashtable<String, String>();
        dictionary.put(TestConstants.PATH_APPLICATIONRESPONSE_201, "5798009811578");
        dictionary.put(TestConstants.PATH_CATALOGUE, "5798009811578");
        dictionary.put(TestConstants.PATH_CATALOGUEDELETION, "5798009811578");
        dictionary.put(TestConstants.PATH_CATALOGUEITEMSPECIFICATIONUPDATE, "5798009811578");
        dictionary.put(TestConstants.PATH_CATALOGUEPRICINGUPDATE, "5798009811578");
        dictionary.put(TestConstants.PATH_CATALOGUEREQUEST, "5798009811578");
        dictionary.put(TestConstants.PATH_CREDITNOTE, "5798009811578");
        dictionary.put(TestConstants.PATH_INVOICE, "5798009811578");
        dictionary.put(TestConstants.PATH_ORDER, "5798009811578");
        dictionary.put(TestConstants.PATH_ORDERCANCELLATION, "5798009811578");
        dictionary.put(TestConstants.PATH_ORDERCHANGE, "5798009811578");
        dictionary.put(TestConstants.PATH_ORDERRESPONSE, "5798009811578");
        dictionary.put(TestConstants.PATH_ORDERRESPONSESIMPLE, "5798009811578");
        dictionary.put(TestConstants.PATH_REMINDER, "5798009811578");
        dictionary.put(TestConstants.PATH_STATEMENT, "5798009811578");
        compareIdentifiers(dictionary);
    }

    public void testFindIdentifierFromXPathWhereString() throws Exception {
        String xpath = "'5798000416604'";

        XmlDocument document = new XmlDocument();
        document.load(TestConstants.PATH_INVOICE);
        EndpointKeyTypeCode keyType = new EndpointKeyTypeCode(0);

        PrefixedNamespace[] prefixedNamespaces = new PrefixedNamespace[]{
                new PrefixedNamespace("urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2", "cac"),
                new PrefixedNamespace("urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2", "cbc"),
                new PrefixedNamespace("urn:oasis:names:specification:ubl:schema:xsd:CoreComponentParameters-2", "ccts"),
                new PrefixedNamespace("urn:oasis:names:specification:ubl:schema:xsd:SpecializedDatatypes-2", "sdt"),
                new PrefixedNamespace("urn:un:unece:uncefact:data:specification:UnqualifiedDataTypesSchemaModule:2", "udt"),
                new PrefixedNamespace("urn:oasis:names:specification:ubl:schema:xsd:OrderResponseSimple-2", "root")
        };

        Identifier identifier = Utilities.getEndpointKeyByXpath(document, xpath, prefixedNamespaces, keyType);

        String expectedValue = "5798000416604";
        String actualValue = identifier.getAsString();
        String message = "Error reading correct identifier from document: " + xpath;
        assertEquals(message, expectedValue, actualValue);
    }

    private void compareIdentifiers(Hashtable<String, String> dictionary) throws Exception {
        for (String key : dictionary.keySet()) {
            Identifier identifier = GetIdentifierValue(key);
            String expectedValue = dictionary.get(key);
            String actualValue = identifier.getAsString();
            String message = "Error reading correct identifier from document: " + key;
            assertEquals(message, expectedValue, actualValue);
        }
    }

    private Identifier GetIdentifierValue(String path) throws Exception {
        XmlDocument document = new XmlDocument();
        document.load(path);

        DocumentTypeConfigSearcher searcher = new DocumentTypeConfigSearcher();
        return Utilities.getReceiverEndpointKey(document, searcher.tryFindUniqueDocumentType(document));
    }
}