package dk.gov.oiosi.xml.schematron.research.bulk;

import dk.gov.oiosi.communication.configuration.DocumentTypeConfig;
import dk.gov.oiosi.xml.XmlDocument;
import dk.gov.oiosi.xml.XmlDocumentException;
import dk.gov.oiosi.xml.XmlException;
import dk.gov.oiosi.xml.schematron.FailedToLoadSchematronStylesheetException;
import dk.gov.oiosi.xml.schematron.SchematronErrorException;
import dk.gov.oiosi.xml.schematron.SchematronValidationConfig;
import dk.gov.oiosi.xml.schematron.research.SchematronComparatorBulkResearchTest;
import dk.gov.oiosi.xml.schematron.sax.SchematronValidatorSAXUtil;
import dk.gov.oiosi.xml.xpath.DocumentXPathResolver;
import dk.gov.oiosi.xml.xpath.PrefixedNamespace;
import org.apache.axiom.om.impl.builder.StAXOMBuilder;
import org.apache.commons.configuration.ConfigurationUtils;
import org.xml.sax.InputSource;

import javax.xml.stream.XMLStreamException;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.sax.SAXSource;
import javax.xml.transform.stream.StreamResult;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

/**
 * Helper class for {@link SchematronComparatorBulkResearchTest}
 *
 * @author Dmitriy Lapko, TrueLink A/S
 */
public class DifferentWayTransformationExecutor {

    private Map<String, Transformer> transformer124Map = new HashMap<String, Transformer>(10);

    private Map<String, Transformer> transformer123Map = new HashMap<String, Transformer>(10);

    public String version124Way(DocumentTypeConfig documentType, XmlDocument xd) throws Exception {
        SchematronValidationConfig config = documentType.getSchematronValidationConfig();
        try {
            Transformer transformer = getNewTransformer(config.getSchematronDocumentPath());
            SchematronValidatorSAXUtil.schematronValidateXmlDocument(xd.getTransformationSource(), transformer, config.getSaxHandlerConfig());
        } catch (SchematronErrorException e) {
            return e.getMessage();
        }
        return null;
    }

    /*
      * Let's also compare when just byte array is passed to transformer instead
      * of built AXIOM document
      */
    public String byteArrayXmlTransformerSax(DocumentTypeConfig documentType, byte[] data) throws Exception {
        SchematronValidationConfig config = documentType.getSchematronValidationConfig();
        try {
            Transformer transformer = getNewTransformer(config.getSchematronDocumentPath());
            SchematronValidatorSAXUtil.schematronValidateXmlDocument(new SAXSource(new InputSource(new ByteArrayInputStream(data))), transformer, config.getSaxHandlerConfig());
        } catch (SchematronErrorException e) {
            return e.getMessage();
        }
        return null;
    }

    public String version123Way(DocumentTypeConfig documentType, XmlDocument xd) throws Exception {
        SchematronValidationConfig svc = documentType.getSchematronValidationConfig();
        try {
            Transformer transformer = getOldTransformer(svc.getSchematronDocumentPath());
            /*
                * Do not use optimized SaxHandler which stops on first error
                */
            XmlDocument oldTransformXml = oldTransformXml(xd, transformer);
            oldValidateResult(oldTransformXml, svc.getErrorXPath(), svc.getErrorMessageXPath());
        } catch (SchematronErrorException e) {
            return e.getMessage();
        }
        return null;
    }

    /**
     * Copied from XsltUtility OIORASP 1.2.3
     */
    private XmlDocument oldTransformXml(XmlDocument document, Transformer transform) throws XmlDocumentException, TransformerException, XMLStreamException {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        StreamResult streamResult = new StreamResult(byteArrayOutputStream);

        transform.transform(new DOMSource(document.getW3Document().getOwnerDocument()), streamResult);

        InputStream inputStream = new ByteArrayInputStream(byteArrayOutputStream.toByteArray());
        StAXOMBuilder builder = new StAXOMBuilder(inputStream);

        return new XmlDocument(builder.getDocumentElement());
    }

    /**
     * Copied from SchematronValidator 1.2.3
     */
    private void oldValidateResult(XmlDocument result, String errorXPath, String errorMessageXPath) throws XmlException {
        PrefixedNamespace[] prefixedNamespaces = new PrefixedNamespace[0];
        boolean hasAnyErrors = DocumentXPathResolver.hasAnyElementsByXpath(result, errorXPath, prefixedNamespaces);
        if (hasAnyErrors) {
            String firstErrorMessage = DocumentXPathResolver.getFirstElementValueByXPath(result, errorMessageXPath,
                    prefixedNamespaces);
            throw new SchematronErrorException(result, firstErrorMessage);
        }
    }

    /*
      * In version 1.2.3 OIORASP transformers were loaded as AXIOM documents and
      * then converted to DOM for DOMSource
      */
    private Transformer getOldTransformer(String path) throws FailedToLoadSchematronStylesheetException {
        Transformer transformer = transformer123Map.get(path);
        if (transformer == null) {
            XmlDocument xd = new XmlDocument();
            try {
                xd.load(path);
                Source xsltSource = new DOMSource(xd.getW3Document());
                TransformerFactory transFact = TransformerFactory.newInstance();
                transformer = transFact.newTransformer(xsltSource);
                transformer123Map.put(path, transformer);
            } catch (Exception ex) {
                throw new FailedToLoadSchematronStylesheetException(path, ex);
            }
        }
        return transformer;
    }

    /*
      * In version 1.3.0 it is proposed to use SAXSource without unnecessary conversion to DOM
      */
    private Transformer getNewTransformer(String path) throws FailedToLoadSchematronStylesheetException {
        Transformer transformer = transformer124Map.get(path);
        if (transformer == null) {
            try {
                InputStream is;
                try {
                    URL url = ConfigurationUtils.locate(path);
                    is = url.openStream();
                } catch (Exception e) {
                    is = new FileInputStream(path);
                }
                Source xsltSource = new SAXSource(new InputSource(is));
                TransformerFactory transFact = TransformerFactory.newInstance();
                transformer = transFact.newTransformer(xsltSource);
                transformer124Map.put(path, transformer);
            } catch (Exception ex) {
                throw new FailedToLoadSchematronStylesheetException(path, ex);
            }
        }
        return transformer;
    }

}